@@ -5,6 +5,7 @@ import os
 import shutil
 from logging import info, warning
 
+from portmod.config import variable_data_dir
 from portmod.config.sets import get_set
 from portmod.globals import env
 from portmod.loader import load_installed_pkg
@@ -27,7 +28,7 @@ def destroy(args):
             print(l10n("destroy-directories"))
             display_num_list(
                 to_remove,
-                [l10n("size", size=get_tree_size(d) / 1024 ** 2) for d in to_remove],
+                [l10n("size", size=get_tree_size(d) / 1024**2) for d in to_remove],
             )
             try:
                 skip = prompt_num_multi(
@@ -64,8 +65,9 @@ def destroy(args):
             else:
                 # This should not occur
                 warning(f"Unable to load installed package {atom} during destruction")
-        info(l10n("removing-directory", path=os.path.join(env.prefix().ROOT, "var")))
-        shutil.rmtree(os.path.join(env.prefix().ROOT, "var"))
+        variable_data = variable_data_dir()
+        info(l10n("removing-directory", path=variable_data))
+        shutil.rmtree(variable_data)
 
     remove_prefix(env.PREFIX_NAME)
 
