@@ -17,6 +17,7 @@ from typing import Callable
 from portmod.globals import env
 from portmod.loader import SandboxedError, load_file
 from portmod.news import validate_news
+from portmod.pybuild import Pybuild
 from portmod.repo import Repo, get_repo_name, get_repo_root
 from portmod.repo.loader import get_atom_from_path
 from portmod.repo.metadata import (
@@ -375,7 +376,7 @@ def scan(args, repo_root: str, err: Callable[[str], None]):
                         for filename in filenames:
                             scan_file(os.path.join(path_root, filename), repo_root, err)
             elif os.path.isfile(root):
-                scan_file(root, repo_root, err)
+                scan_file(os.path.abspath(root), repo_root, err)
 
 
 def manifest(args, _repo_root: str, err: Callable[[str], None]):
@@ -401,11 +402,105 @@ def manifest(args, _repo_root: str, err: Callable[[str], None]):
                 err(f"{root} is not a pybuild file!")
 
 
-def main():
-    """
-    Main function for the inquisitor executable
-    """
+def test_install(package: Pybuild):
+    from itertools import combinations
 
+    from portmod.config.use import add_use, remove_use
+    from portmod.merge import configure
+    from portmod.query import get_flag_string
+    from portmodlib.usestr import check_required_use
+
+    try:
+        all_combinations = set()
+        for i in range(len(package.IUSE_EFFECTIVE) + 1):
+            all_combinations |= set(combinations(package.IUSE_EFFECTIVE, i))
+        configurations = list(
+            filter(
+                lambda flags: check_required_use(
+                    package.REQUIRED_USE_EFFECTIVE, set(flags), package.valid_use
+                ),
+                all_combinations,
+            )
+        )
+        for configuration in configurations:
+            print(
+                "Testing configuration",
+                get_flag_string(
+                    "USE",
+                    configuration,
+                    set(package.IUSE_EFFECTIVE) - set(configuration),
+                ),
+            )
+            for flag in package.IUSE_EFFECTIVE:
+                if flag in configuration:
+                    add_use(flag, package.ATOM)
+                else:
+                    add_use(flag, package.ATOM, disable=True)
+            configure([package.ATOM], select=False)
+
+    finally:
+        for flag in package.IUSE_EFFECTIVE:
+            remove_use(flag, package.ATOM)
+
+
+def test_install_cli(args, repo_root, _err):
+    from types import SimpleNamespace
+
+    from portmod._cli.select import add_prefix_repo, list_profiles
+    from portmod.config.profiles import set_profile
+    from portmod.functools import clear_system_cache
+    from portmod.loader import load_file
+    from portmod.prefix import add_prefix, get_prefixes
+
+    from .destroy import destroy
+
+    # Enable special testing behaviour like auto-applying configuration changes
+    env.TESTING = True
+
+    if args.no_confirm:
+        env.INTERACTIVE = False
+
+    try:
+        prefixes = get_prefixes()
+        if args.prefix not in prefixes:
+            test_prefix = "test0"
+            i = 0
+            while test_prefix in prefixes:
+                i += 1
+                test_prefix = "test" + str(i)
+
+            add_prefix(test_prefix, args.arch)
+            # FIXME: Should all profiles be tested?
+            # we can only feasibly do it if creating a prefix from scratch.
+            # If using an existing prefix, we should just use the existing profile
+
+            env.set_prefix(test_prefix)
+            add_prefix_repo(get_repo_name(repo_root))
+            profiles = list_profiles(args.arch)
+            print(f"Using profile {profiles[0]}")
+            set_profile(profiles[0])
+            clear_system_cache()
+        elif args.prefix is not None:
+            if not prefixes[args.prefix].arch == args.arch:
+                raise Exception(
+                    f"Architecture of prefix {args.prefix} does not match the test architecture"
+                )
+            test_prefix = args.prefix
+            env.set_prefix(test_prefix)
+
+        for file in args.files:
+            test_install(load_file(file))
+
+    finally:
+        # Make sure destruction is done in non-interactive mode
+        # User didn't create the test prefix, so they don't care about preserving
+        # configuration
+        env.INTERACTIVE = False
+        if args.prefix is None and not env.DEBUG:
+            destroy(SimpleNamespace(remove_config=True, preserve_root=False))
+
+
+def get_parser():
     common = argparse.ArgumentParser(add_help=False)
     add_logging_arguments(common)
     common.add_argument("--debug", help=l10n("merge-debug-help"), action="store_true")
@@ -455,10 +550,32 @@ def main():
         help="scope to process. If not provided defaults to the current working directory",
         nargs="*",
     )
+    test_install_parser = subparsers.add_parser(
+        "test-install", help="Tests package installation", parents=[common]
+    )
+    test_install_parser.add_argument("arch", help="Architecture to test")
+    test_install_parser.add_argument(
+        "files", metavar="FILE", help="Package files to test", nargs="*"
+    )
+    test_install_parser.add_argument("--prefix", help="Optional existing prefix to use")
+    test_install_parser.add_argument(
+        "--no-confirm", help="If set, run in non-interactive mode", action="store_true"
+    )
 
     scan_parser.set_defaults(func=scan)
     manifest_parser.set_defaults(func=manifest)
     commit_msg_parser.set_defaults(func=commit_message)
+    test_install_parser.set_defaults(func=test_install_cli)
+
+    return parser
+
+
+def main():
+    """
+    Main function for the inquisitor executable
+    """
+
+    parser = get_parser()
 
     args = parser.parse_args()
     init_logger(args)
