@@ -53,7 +53,14 @@ def filter_mods(mods):
 
 
 def add_merge_parser(subparsers, parents):
-    parser = subparsers.add_parser("merge", help=l10n("merge-help"), parents=parents)
+    parser = subparsers.add_parser(
+        "merge",
+        help=l10n("merge-help"),
+        description=l10n("merge-desc"),
+        parents=parents,
+        conflict_handler="resolve",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     parser.add_argument(
         "packages",
         metavar=atom_metavar(archive=True, sets=True),
@@ -78,10 +85,10 @@ def add_merge_parser(subparsers, parents):
         "-1", "--oneshot", help=l10n("oneshot-help"), action="store_true"
     )
     parser.add_argument("-O", "--nodeps", help=l10n("nodeps-help"), action="store_true")
+    parser.add_argument("-u", "--update", help=l10n("update-help"), action="store_true")
     parser.add_argument(
         "-n", "--noreplace", help=l10n("noreplace-help"), action="store_true"
     )
-    parser.add_argument("-u", "--update", help=l10n("update-help"), action="store_true")
     parser.add_argument("-N", "--newuse", help=l10n("newuse-help"), action="store_true")
     parser.add_argument(
         "-e", "--emptytree", help=l10n("emptytree-help"), action="store_true"
@@ -106,7 +113,8 @@ def add_merge_parser(subparsers, parents):
         metavar=l10n("yes-or-no"),
         help=l10n("merge-deselect-help"),
     )
-    parser.add_argument("--sort-vfs", help=l10n("sort-vfs-help"), action="store_true")
+    parser.add_argument("--sort-vfs", help=argparse.SUPPRESS, action="store_true")
+    parser.add_argument("--debug", help=l10n("merge-debug-help"), action="store_true")
 
     parser.set_defaults(func=merge_main)
 
@@ -114,6 +122,7 @@ def add_merge_parser(subparsers, parents):
 @exclusive_lock()
 def merge_main(args):
     atoms = filter_mods(args.packages)
+    env.DEBUG = args.debug
 
     if args.nodeps and args.depclean:
         error(l10n("nodeps-depclean"))
@@ -123,19 +132,16 @@ def merge_main(args):
         # If deselect is supplied (is not None), only deselect if not removing.
         # If removing, remove normally, but deselect depending on supplied value.
         if args.deselect and not (args.unmerge or args.depclean):
-            deselect(atoms, no_confirm=args.no_confirm)
+            deselect(atoms)
         else:
             try:
                 configure(
                     atoms,
                     delete=args.unmerge,
                     depclean=args.depclean,
-                    no_confirm=args.no_confirm,
                     oneshot=args.oneshot,
                     verbose=args.verbose,
-                    update=args.update,
-                    newuse=args.newuse,
-                    noreplace=args.noreplace or args.update or args.newuse,
+                    update=args.update or args.newuse or args.noreplace,
                     nodeps=args.nodeps,
                     deselect=args.deselect,
                     select=args.select,
