@@ -22,33 +22,41 @@ from portmod.source import HashAlg
 from portmodlib.l10n import l10n
 
 
-def create_manifest(mod: Pybuild):
+def create_manifest(pkg: Pybuild):
     """
     Automatically downloads mod DIST files (if not already in cache)
     and creates a manifest file
     """
-    pybuild_file = mod.FILE
-    manifest = Manifest(manifest_path(pybuild_file))
-    manifest.entries = {}
+    manifest = Manifest(manifest_path(pkg.FILE))
 
-    directory = os.path.dirname(pybuild_file)
+    existing_sources = set()
 
-    for file in glob(os.path.join(directory, "*.pybuild")):
+    # Collect the names of existing files
+    for file in glob(os.path.join(os.path.dirname(pkg.FILE), "*.pybuild")):
+        if file == pkg.FILE:
+            continue
         thismod = load_file(file)
-        sources = thismod._get_sources(matchall=True)
+        existing_sources |= {
+            source.name for source in thismod._get_sources(matchall=True)
+        }
 
-        # Add sources to manifest
-        for source in sources:
-            filename = download_source(mod, source)
-            if filename is None:
-                error("Unable to get shasum for unavailable file " + source.name)
-                continue
+    # Remove files not referenced by any of the package files
+    # This will also remove files, if any, referenced by the package file being added to the manifest
+    for name in {name for name in manifest.entries if name not in existing_sources}:
+        del manifest.entries[name]
 
-            manifest.add_entry(
-                ManifestEntry.from_path(
-                    FileType.DIST, filename, source.name, [HashAlg.BLAKE3, HashAlg.MD5]
-                )
+    # Add sources from the package file to manifest
+    for source in load_file(pkg.FILE)._get_sources(matchall=True):
+        filename = download_source(pkg, source)
+        if filename is None:
+            error("Unable to get shasum for unavailable file " + source.name)
+            continue
+
+        manifest.add_entry(
+            ManifestEntry.from_path(
+                FileType.DIST, filename, source.name, [HashAlg.BLAKE3, HashAlg.MD5]
             )
+        )
 
     # Write changes to manifest
     manifest.write()
