@@ -1,42 +1,29 @@
 # Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
-from collections import defaultdict
-from typing import Dict, List
-
+from portmod.lock import exclusive_lock
 from portmod.merge import configure
 from portmod.prompt import prompt_num_multi
 from portmod.query import display_search_results, query
 from portmodlib.colour import bright, lblue
 from portmodlib.l10n import l10n
 
-from .pybuild import Pybuild
-
 
 def search_main(args):
     pkgs = list(
         query(
-            ["NAME", "ATOM", "DESC"],
             " ".join(args.query),
-            strip=True,
-            squelch_sep=True,
-            insensitive=True,
         )
     )
-    grouped: Dict[str, List[Pybuild]] = defaultdict(list)
-    for pkg in pkgs:
-        grouped[pkg.CPN].append(pkg)
-
-    sortedgroups = sorted(grouped.values(), key=lambda group: group[0].CPN)
-
-    display_search_results(sortedgroups, numbers=True)
+    display_search_results(pkgs, numbers=True)
 
     try:
-        selection = selection_prompt([group[0].CPN for group in sortedgroups])
+        selection = selection_prompt([pkg.cpn for pkg in pkgs])
     except EOFError:
         return
     if selection:
-        configure(selection)
+        with exclusive_lock():
+            configure(selection)
 
 
 def selection_prompt(atoms):
