@@ -1,13 +1,13 @@
 # Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
+import logging
 import sys
 import traceback
 from logging import error
 from typing import Optional
 
-from portmod.config.use import InvalidFlag, add_use, remove_use
-from portmod.globals import env
+from portmod.config.use import InvalidFlag, add_global_use, add_use, remove_use
 from portmod.lock import exclusive_lock
 from portmodlib.atom import Atom
 from portmodlib.l10n import l10n
@@ -42,14 +42,20 @@ def add_use_parser(subparsers, parents):
 
             if args.E or args.D:
                 if args.E:
-                    add_use(args.E, atom)
+                    if atom:
+                        add_use(args.E, atom)
+                    else:
+                        add_global_use(args.E)
                 elif args.D:
-                    add_use(args.D, atom, disable=True)
+                    if atom:
+                        add_use(args.D, atom, disable=True)
+                    else:
+                        add_global_use(args.D, disable=True)
 
             if args.R:
                 remove_use(args.R, atom)
         except InvalidFlag as e:
-            if env.DEBUG:
+            if logging.root.level <= logging.DEBUG:
                 traceback.print_exc()
             error(f"{e}")
         except Exception as e:
