@@ -6,8 +6,9 @@
 import os
 from typing import Optional, Set
 
+from portmod.config import variable_data_dir
+from portmod.config.profiles import get_system
 from portmod.globals import env
-from portmod.repo.profiles import get_system
 from portmodlib.atom import Atom, atom_sat
 
 BUILTIN_SETS = {
@@ -65,11 +66,10 @@ def get_set(package_set: str, parent_dir: Optional[str] = None) -> Set[Atom]:
     if package_set == "world":
         return get_set("system") | get_set("selected")
     if package_set == "selected":
-        return (
-            get_set("selected-packages")
-            | get_set("selected-sets")
-            | get_set("local-packages")
-        )
+        selected = get_set("selected-packages") | get_set("local-packages")
+        for selected_set in get_set("selected-sets"):
+            selected |= get_set(selected_set)
+        return selected
     if package_set == "system":
         return get_system()
     if package_set == "installed":
@@ -105,11 +105,11 @@ def _get_set_path(package_set: str, parent_dir: Optional[str] = None) -> str:
     if package_set == "installed":
         raise RuntimeError("The @installed set cannot be modified by this function!")
     if package_set == "selected-packages":
-        return os.path.join(env.prefix().VAR_SET_DIR, "world")
+        return os.path.join(variable_data_dir(), "sets", "world")
     if package_set == "selected-sets":
-        return os.path.join(env.prefix().VAR_SET_DIR, "world_sets")
+        return os.path.join(variable_data_dir(), "sets", "world_sets")
     if package_set in ("rebuild"):
-        return os.path.join(env.prefix().VAR_SET_DIR, package_set)
+        return os.path.join(variable_data_dir(), "sets", package_set)
     return os.path.join(parent_dir, package_set)
 
 
