@@ -8,9 +8,10 @@ import sys
 import urllib.parse
 from base64 import b16encode, b64decode
 from logging import info
-from typing import AbstractSet, Dict, Iterable, List, Optional
+from typing import AbstractSet, Dict, Iterable, List, Optional, Set
 
 from portmod.config import get_config
+from portmod.config.license import _get_pkg_license_groups
 from portmod.globals import env
 from portmod.parsers.manifest import FileType
 from portmod.pybuild import Pybuild
@@ -20,15 +21,15 @@ from portmodlib.l10n import l10n
 from portmodlib.source import HashAlg, Source
 from portmodlib.usestr import use_reduce
 
-from .config.use import get_use
-from .repo import get_repo, get_repo_root
-from .repo.metadata import get_license_groups
-
 
 class RemoteHashError(Exception):
     """Exception indicating an unexpected download file"""
 
 
+class SourceUnfetchable(Exception):
+    """Exception indicating an unexpected download file"""
+
+
 def get_filename(basename: str, path: Optional[str] = None) -> str:
     """
     By default returns the location of the local cached version of the source
@@ -47,15 +48,7 @@ def mirrorable(mod: Pybuild, enabled_use: Optional[AbstractSet[str]] = None) ->
     # FIXME: Determine which sources have use requirements
     # that don't enable mirror or fetch
     if "mirror" not in mod.RESTRICT and "fetch" not in mod.RESTRICT:
-        redis: Iterable[str]
-        if mod.INSTALLED:
-            redis = get_license_groups(get_repo(mod.REPO).location).get(
-                "REDISTRIBUTABLE", []
-            )
-        else:
-            redis = get_license_groups(get_repo_root(mod.FILE)).get(
-                "REDISTRIBUTABLE", []
-            )
+        redis = _get_pkg_license_groups(mod).get("REDISTRIBUTABLE", [])
 
         def is_license_redis(group):
             if not group:
@@ -80,23 +73,21 @@ def mirrorable(mod: Pybuild, enabled_use: Optional[AbstractSet[str]] = None) ->
     return False
 
 
-def fetchable(mod: Pybuild) -> List[SourceManifest]:
+def fetchable(mod: Pybuild, enabled_use: Set[str]) -> List[SourceManifest]:
     """
     Returns the list of fetchable sources associated with a mod
     A source can be fetched if it is mirrorable,
     or if it has a URI
     """
-    use, _ = get_use(mod)
-
-    restricted = use_reduce(mod.RESTRICT, use, flat=True)
+    restricted = use_reduce(mod.RESTRICT, enabled_use, flat=True)
     if "fetch" in restricted:
         return []
 
-    if "mirror" not in restricted and mirrorable(mod, use):
-        return mod.get_default_sources()
+    if "mirror" not in restricted and mirrorable(mod, enabled_use):
+        return mod.get_sources(enabled_use)
 
     can_fetch = []
-    for source in mod.get_default_sources():
+    for source in mod.get_sources(enabled_use):
         parsedurl = urllib.parse.urlparse(source.url)
         if parsedurl.scheme:
             can_fetch.append(source)
@@ -106,9 +97,12 @@ def fetchable(mod: Pybuild) -> List[SourceManifest]:
 
 def progress_write(request, filepath, start=0, mode="wb", size: Optional[int] = None):
     if sys.stdout.isatty():
+        try:
+            from progressbar import GranularBar as Bar
+        except ImportError:
+            from progressbar import Bar
         from progressbar import (
             ETA,
-            Bar,
             DataSize,
             FileTransferSpeed,
             Percentage,
@@ -283,11 +277,11 @@ def find_download(source: Source) -> Optional[str]:
     )
 
 
-def is_downloaded(mod: Pybuild) -> bool:
+def is_downloaded(mod: Pybuild, enabled_use: Set[str]) -> bool:
     """
     Returns true if all the mod's sources can be found
     """
-    for source in mod.get_default_sources():
+    for source in mod.get_sources(enabled_use):
         cached = find_download(source)
         if cached is None:
             return False
@@ -331,7 +325,7 @@ def download_source(mod, source: Source) -> str:
         return cached
     elif not fetch:
         # Mod cannot be fetched and is not already in cache. abort.
-        raise Exception(l10n("source-unfetchable", source=source))
+        raise SourceUnfetchable(l10n("source-unfetchable", source=source))
     else:
         parsedurl = urllib.parse.urlparse(source.url)
 
@@ -364,7 +358,7 @@ def download_source(mod, source: Source) -> str:
 
             return filename
 
-        raise Exception(l10n("source-unfetchable", source=source))
+        raise SourceUnfetchable(l10n("source-unfetchable", source=source))
 
 
 def download_mod(
@@ -399,11 +393,20 @@ def get_total_download_size(mods: Iterable[Pybuild]):
     return "{:.3f} MiB".format(download_bytes / 1024 / 1024)
 
 
-def get_download_size(mods: Iterable[Pybuild]) -> float:
+def get_download_size(packages: Dict[Pybuild, Set[str]]) -> float:
+    """
+    Returns the download size for the packages in the given configuration
+
+    args:
+        packages: A dictionary mapping each package to check to its enabled USE flags
+
+    returns:
+        The size of the downloads in MiB
+    """
     download_bytes = 0
-    for mod in mods:
+    for mod, enabled_use in packages.items():
         manifest_file = mod.get_manifest()
-        sources = mod.get_default_sources()
+        sources = mod.get_sources(enabled_use)
         for manifest in manifest_file.entries.values():
             source = next(
                 (source for source in sources if source.name == manifest.name), None
