@@ -11,7 +11,7 @@ from typing import AbstractSet, Iterable, List, Set, Tuple, Union
 from portmodlib.fs import is_parent
 from portmodlib.l10n import l10n
 
-from .config import get_config
+from .config import get_config, get_config_value
 from .globals import env
 from .perms import Permissions
 from .win32 import get_personal
@@ -192,6 +192,12 @@ def sandbox_execute(
             [["--ro-bind", dpath, path] for dpath, path in zip(sym_dests, syms)], []
         )
 
+        # Needs to be a list of command arguments
+        # I.e. NOT a string
+        user = get_config_value("_SANDBOX_PERMISSIONS", [])
+        if not isinstance(user, list):
+            raise TypeError("_SANDBOX_PERMISSIONS must be a list of arguments to bwrap")
+
         sandbox_command = (
             [_required_exe("bwrap")]
             + ro_bind
@@ -207,6 +213,7 @@ def sandbox_execute(
                 os.getcwd(),
                 "--die-with-parent",
             ]
+            + user
         )
         if permissions.network:
             sandbox_command.append("--share-net")
@@ -268,6 +275,16 @@ def sandbox_execute(
         # using sandboxie's start.exe would not give us any stdout or stderr.
         add_command("set", "ForceFolder", os.getcwd())
 
+        # Needs to be a list of command argument tuples
+        user = get_config_value("_SANDBOX_PERMISSIONS", [])
+        if not isinstance(user, list):
+            raise TypeError(
+                "_SANDBOX_PERMISSIONS must be a list with sbieini commands in the order of $command $type $value. "
+                'E.g. ["append", "ClosedFilePath", "filename.txt"]'
+            )
+        for user_command, typ, value in user:
+            add_command(user_command, typ, value)
+
         sandbox_command = []
     elif sys.platform == "darwin":
         sandbox_command = [_required_exe("sandbox-exec"), "-p"]
@@ -305,6 +322,8 @@ def sandbox_execute(
                   (literal "/dev/fd")
                   (literal "/dev/random")
                   (literal "/dev/urandom")
+                  (literal "/var/db")
+                  (literal "/var/db/xcode_select_link")
                   (literal "/")
                 )
             """
@@ -316,6 +335,7 @@ def sandbox_execute(
                 "/etc",
                 "/private/etc",
                 "/Library",
+                "/opt",
             }
 
         if not permissions.tmp:
@@ -351,6 +371,14 @@ def sandbox_execute(
         sandbox_profile += """
             )"""
 
+        # Must be a string
+        user = get_config_value("_SANDBOX_PERMISSIONS", "")
+        if not isinstance(user, str):
+            raise TypeError(
+                "_SANDBOX_PERMISSIONS must be a string with sandbox-exec profile contents"
+            )
+        sandbox_profile += user
+
         sandbox_command.append(sandbox_profile)
     else:
         raise Exception("Unsupported Platform")
