@@ -11,7 +11,7 @@ import shutil
 import subprocess
 import sys
 import traceback
-from functools import lru_cache, wraps
+from functools import wraps
 from logging import debug, warning
 from typing import (
     Any,
@@ -29,7 +29,8 @@ from typing import (
 import portmod
 from portmod.config import get_config
 from portmod.execute import sandbox_execute
-from portmod.functools import prefix_aware_cache
+from portmod.functools import install_cache, prefix_aware_cache, system_cache
+from portmod.vdb import vdb_path
 from portmodlib.atom import Atom, FQAtom, atom_sat
 from portmodlib.colour import green
 from portmodlib.execute import execute
@@ -66,8 +67,14 @@ class AmbiguousAtom(Exception):
 class SandboxedError(Exception):
     """Error raised when a sandboxed command fails"""
 
+    def __init__(self, message: str):
+        self.message = message
 
-@lru_cache()
+    def __str__(self):
+        return f"An error was encountered when execuring code inside the sandbox: {self.message}"
+
+
+@system_cache
 def _state_path(file) -> str:
     atom = get_atom_from_path(file)
     return os.path.join(env.TMP_DIR, atom.C, atom.P, "state")
@@ -173,7 +180,7 @@ def load_module(file: str, state):
     )
 
 
-@lru_cache()
+@system_cache
 def _get_library_dirs(path: str) -> Set[str]:
     """
     Returns the directories containing the libraries
@@ -237,12 +244,13 @@ def _sandbox_execute(
     if not os.path.exists(curdir or env.TMP_DIR):
         os.makedirs(curdir or env.TMP_DIR)
     os.chdir(curdir or env.TMP_DIR)
-    ro_paths = set(permissions.ro_paths)
-    ro_paths.add(env.CONFIG_DIR)
-    for repo in env.REPOS:
-        ro_paths.add(repo.location)
-    # Python site packages directories, etc.
-    ro_paths |= set(sys.path)
+    ro_paths = (
+        set(permissions.ro_paths)
+        | {env.CONFIG_DIR, env.TMP_VDB, os.path.dirname(abspath)}
+        | {repo.location for repo in env.REPOS}
+        # Python site packages directories, etc.
+        | set(sys.path)
+    )
 
     # Binary search paths
     # Relative paths are ignored,
@@ -254,7 +262,6 @@ def _sandbox_execute(
 
     if not curdir:
         ro_paths.add(env.TMP_DIR)
-    ro_paths.add(os.path.dirname(abspath))
     # Detect Libraries used by executables in case of non-standard library locations
     for executable in ["python", "git", "bsatool"]:
         exec_path = shutil.which(executable)
@@ -272,7 +279,7 @@ def _sandbox_execute(
         action,
     ]
     if file_type == "pybuild":
-        ro_paths.add(env.prefix().INSTALLED_DB)
+        ro_paths.add(vdb_path())
     rw_paths = set(permissions.rw_paths)
     rw_paths.add(env.PYBUILD_TMP_DIR)
     if save_state:
@@ -395,7 +402,7 @@ def __safe_load(user_function: Callable[..., V]) -> Callable[..., Optional[V]]:
             raise e.previous
         except Exception as e:
             warning(e)
-            if env.DEBUG:
+            if logging.root.level <= logging.DEBUG:
                 traceback.print_exc()
             warning(l10n("could-not-load-pybuild", file=name))
             if env.ALLOW_LOAD_ERROR:
@@ -405,6 +412,7 @@ def __safe_load(user_function: Callable[..., V]) -> Callable[..., Optional[V]]:
     return cast(Callable[..., Optional[V]], decorating_function)
 
 
+@install_cache
 def load_installed_pkg(atom: Atom) -> Optional[InstalledPybuild]:
     """Loads packages from the installed database"""
     path = find_installed_path(atom)
@@ -422,6 +430,7 @@ def load_installed_pkg(atom: Atom) -> Optional[InstalledPybuild]:
     return None
 
 
+@prefix_aware_cache
 def load_pkg_fq(atom: FQAtom) -> Pybuild:
     """
     Loads package matching fully qualified atom.
@@ -430,6 +439,7 @@ def load_pkg_fq(atom: FQAtom) -> Pybuild:
         FileNotFoundError: If the package cannot be found
         AmbiguousAtom: If multiple packages match the given atom
     """
+    assert isinstance(atom, FQAtom)
     if atom.R.endswith("::installed") or atom.R == "installed":
         installed = load_installed_pkg(atom)
         if installed:
@@ -453,6 +463,7 @@ def load_pkg_fq(atom: FQAtom) -> Pybuild:
     raise FileNotFoundError(l10n("not-found", atom=atom))
 
 
+@install_cache
 def load_pkg(atom: Atom, *, repo_name: Optional[str] = None) -> List[Pybuild]:
     """
     Loads all mods matching the given atom
