@@ -5,17 +5,23 @@ import io
 import logging
 import os
 import shutil
+import sys
 from logging import error, info, warning
 from typing import Dict, Iterable, Optional
 
+from portmod.pybuild import Pybuild
 from portmodlib.atom import Atom, QualifiedAtom, atom_sat
 from portmodlib.colour import bright, green, lblue, lgreen, red, yellow
 from portmodlib.l10n import l10n
+from portmodlib.module_util import _add_redirection
 
 from ._deps import resolve
+from .cfg_protect import get_protected_path, get_redirections, handle_cfg_protect
 from .config import get_config
+from .config.license import _user_package_accept_license_path
+from .config.profiles import get_system
 from .config.sets import BUILTIN_SETS, add_set, get_set, remove_set
-from .config.use import add_use
+from .config.use import _user_package_use_path, add_use
 from .download import fetchable, find_download, is_downloaded
 from .globals import env
 from .loader import (
@@ -28,13 +34,15 @@ from .loader import (
 )
 from .modules import clear_module_updates, require_module_updates, update_modules
 from .package import install_pkg, remove_pkg
+from .parsers.flags import add_flag
 from .perms import Permissions
 from .prompt import prompt_bool
 from .query import FlagDesc, LocalFlagDesc, get_flag_desc
 from .rebuild import get_rebuild_manifest
-from .repo.keywords import add_keyword
+from .repo import get_repo
+from .repo.keywords import _user_package_accept_keywords_path, add_keyword
 from .repo.loader import commit_moved
-from .repo.profiles import get_system
+from .repo.metadata import get_license
 from .transactions import (
     Delete,
     New,
@@ -46,6 +54,7 @@ from .transactions import (
 )
 from .tsort import CycleException
 from .util import KeywordDep, LicenseDep, select_package
+from .vdb import VDB
 from .vfs import clear_vfs_sort, require_vfs_sort, sort_vfs, vfs_needs_sorting
 
 
@@ -67,8 +76,10 @@ def global_updates():
     update_modules()
     clear_module_updates()
 
+    handle_cfg_protect(get_redirections())
 
-def deselect(pkgs: Iterable[str], *, no_confirm: bool = False):
+
+def deselect(pkgs: Iterable[str]):
     all_to_remove = []
 
     for name in pkgs:
@@ -88,7 +99,7 @@ def deselect(pkgs: Iterable[str], *, no_confirm: bool = False):
         print(">>> " + l10n("no-matching-world-atom"))
         return
 
-    if no_confirm or prompt_bool(bright(l10n("remove-from-world-qn"))):
+    if not env.INTERACTIVE or prompt_bool(bright(l10n("remove-from-world-qn"))):
         for mod in all_to_remove:
             remove_set("selected-packages", mod)
 
@@ -98,8 +109,31 @@ def _update_configuration(
     license_changes: Iterable[LicenseDep],
     use_changes: Iterable[UseDep],
     *,
-    no_confirm: bool,
+    protect: bool,
 ):
+    def protected_changes_required():
+        info("")
+        warning(
+            l10n(
+                "configuration-changes-required",
+                command=f"portmod {env.PREFIX_NAME} cfg-update",
+            ),
+        )
+        sys.exit(1)
+
+    def create_protect_file(path: str):
+        # get_protected_path will return the same path
+        # if the original file does not exist
+        if not os.path.exists(license_file):
+            with open(license_file, "w", encoding="utf-8"):
+                pass
+        protect_file = get_protected_path(path)
+        try:
+            shutil.copy2(path, protect_file)
+        except FileNotFoundError:
+            pass
+        _add_redirection(protect_file, path)
+
     if keyword_changes:
         for keyword in keyword_changes:
             if keyword.masked:
@@ -120,18 +154,45 @@ def _update_configuration(
                 c = yellow
             print("    {} {}".format(green(keyword.atom), c(keyword.keyword)))
 
-        if no_confirm or prompt_bool(l10n("apply-changes-qn")):
+        if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
+            protect_file = None
+            keyword_file = _user_package_accept_keywords_path()
+            if protect:
+                create_protect_file(keyword_file)
+
             for keyword in keyword_changes:
-                add_keyword(keyword.atom, keyword.keyword)
+                add_keyword(keyword.atom, keyword.keyword, protect_file=protect_file)
         else:
-            return
+            sys.exit(1)
 
     if license_changes:
-        # TODO: For EULA licenses, display the license and prompt the user to accept
-        print(l10n("necessary-license-changes"))
+        warning(l10n("necessary-license-changes"))
+        protect_file = None
         for license in license_changes:
             print("    {} {}".format(green(license.atom), license.license))
-        return
+            # For EULA licenses, display the license and prompt the user to accept
+            if license.is_eula and env.INTERACTIVE:
+                print()
+
+                def indent(text: str) -> str:
+                    return "\n".join(["    " + line for line in text.split("\n")])
+
+                print("    ---", l10n("license-start", license=license.license), "---")
+                print(
+                    indent(
+                        get_license(get_repo(license.repo).location, license.license)
+                    )
+                )
+                print("    ---", l10n("license-end", license=license.license), "---")
+
+            if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
+                license_file = _user_package_accept_license_path()
+                if protect and not protect_file:
+                    create_protect_file(license_file)
+
+                add_flag(protect_file or license_file, license.atom, license.license)
+            else:
+                sys.exit(1)
 
     if use_changes:
         display_flags: Dict[str, FlagDesc] = {}
@@ -139,7 +200,7 @@ def _update_configuration(
             flag = use.flag.lstrip("-")
             desc = get_flag_desc(load_pkg_fq(use.atom), flag)
             if isinstance(desc, LocalFlagDesc):
-                display_flags[desc.pkg.ATOM.use(flag)] = desc
+                display_flags[Atom(desc.pkg.ATOM.CPF).use(flag)] = desc
             else:
                 display_flags[flag] = desc or FlagDesc("<missing description>")
 
@@ -149,29 +210,70 @@ def _update_configuration(
         print()
         print(l10n("necessary-flag-changes"))
         for use in use_changes:
+            comment = "\n    ".join(use.comment)
+            if comment:
+                comment += "\n    "
             if use.flag.startswith("-") and use.oldvalue == use.flag.lstrip("-"):
                 print(
-                    "    {} {} # {}".format(
-                        lblue(use.atom), red(use.flag), l10n("enabled-comment")
+                    "   {}{} {} # {}".format(
+                        comment,
+                        lblue(use.atom.CPF),
+                        red(use.flag),
+                        l10n("enabled-comment"),
                     )
                 )
             elif not use.flag.startswith("-") and use.oldvalue == "-" + use.flag:
                 print(
-                    "    {} {} # {}".format(
-                        green(use.atom), red(use.flag), l10n("disabled-comment")
+                    "    {}{} {} # {}".format(
+                        comment,
+                        green(use.atom.CPF),
+                        red(use.flag),
+                        l10n("disabled-comment"),
                     )
                 )
             else:
-                print("    {} {}".format(green(use.atom), red(use.flag)))
-        if no_confirm or prompt_bool(l10n("apply-changes-qn")):
+                print("    {}{} {}".format(comment, green(use.atom.CPF), red(use.flag)))
+        if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
+            protect_file = None
+            if protect:
+                use_file = _user_package_use_path()
+                protect_file = get_protected_path(use_file)
+                try:
+                    shutil.copy2(use_file, protect_file)
+                except FileNotFoundError:
+                    pass
+                _add_redirection(protect_file, use_file)
+
             for use in use_changes:
                 add_use(
                     use.flag.lstrip("-"),
                     Atom(use.atom.CPF),
                     use.flag.startswith("-"),
+                    use.comment,
+                    protect_file=protect_file,
                 )
         else:
-            return
+            sys.exit(1)
+    if protect and (keyword_changes or use_changes or license_changes):
+        protected_changes_required()
+
+
+def get_messages(pkg: Pybuild):
+    """
+    Produces messages produced by Pybuild1.warn or Pybuild1.info
+    during package phase functions
+    """
+    warning_path = os.path.join(env.WARNINGS_DIR, pkg.ATOM.CPF)
+    info_path = os.path.join(env.WARNINGS_DIR, pkg.ATOM.CPF)
+    messages = []
+    if os.path.exists(warning_path):
+        with open(warning_path, "r") as file:
+            messages.append(("warn", file.read()))
+
+    if os.path.exists(info_path):
+        with open(info_path, "r") as file:
+            messages.append(("info", file.read()))
+    return messages
 
 
 def configure(
@@ -180,12 +282,9 @@ def configure(
     delete: bool = False,
     depclean: bool = False,
     auto_depclean: bool = False,
-    no_confirm: bool = False,
     oneshot: bool = False,
     verbose: bool = False,
     update: bool = False,
-    newuse: bool = False,
-    noreplace: bool = False,
     nodeps: bool = False,
     deselect: Optional[bool] = None,
     select: Optional[bool] = None,
@@ -193,8 +292,6 @@ def configure(
     emptytree: bool = False,
 ):
     global_prepare()
-    # Slow import
-    import git
 
     # Ensure that we always get the config before performing operations on packages
     # This way the config settings will be available as environment variables.
@@ -247,9 +344,25 @@ def configure(
             transactions.append(Delete(ipkg))
     elif nodeps:
         fqatoms = []
+        enabled_flags = {}
+        usedeps = []
         for atom in atomlist:
             pkg, _ = select_package(load_pkg(atom))
             fqatoms.append(pkg.ATOM)
+            enabled_flags[pkg.ATOM] = pkg.get_use()
+            for flag in atom.USE:
+                usedeps.append(
+                    UseDep(
+                        pkg.ATOM,
+                        flag,
+                        None,
+                        ["# Use requirement passed on command line"],
+                    )
+                )
+                if flag.startswith("-"):
+                    enabled_flags[pkg.ATOM].remove(flag.lstrip("-"))
+                else:
+                    enabled_flags[pkg.ATOM].add(flag)
 
         selected_cpn = set()
         for atom in selected:
@@ -260,22 +373,21 @@ def configure(
             fqatoms,
             [],
             set() if oneshot or depclean else selected_cpn,
-            [],
-            noreplace=noreplace,
+            usedeps,
+            enabled_flags,
+            update=update,
             emptytree=emptytree,
         )
     else:
         transactions = resolve(
             atomlist,
             to_remove,
-            set() if noreplace else explicit,
+            explicit,
             set() if oneshot or depclean else selected,
             set() if oneshot or depclean else selected_sets,
             deep=deep
             or (depclean and not to_remove),  # No argument depclean implies deep
             update=update,
-            newuse=newuse,
-            noreplace=noreplace or depclean or update or newuse,
             depclean=auto_depclean or depclean,
             emptytree=emptytree,
         )
@@ -285,7 +397,7 @@ def configure(
     # Inform user of changes
     if transactions.pkgs:
         # Don't print transaction list when in quiet mode and no-confirm is passed
-        if not no_confirm or logging.root.level < logging.WARN:
+        if env.INTERACTIVE or logging.root.level < logging.WARN:
             if delete or depclean:
                 print(l10n("to-remove"))
             else:
@@ -309,7 +421,11 @@ def configure(
         )
         use_changes = list(filter(lambda x: isinstance(x, UseDep), transactions.config))
         _update_configuration(
-            keyword_changes, license_changes, use_changes, no_confirm=no_confirm
+            keyword_changes,
+            license_changes,
+            use_changes,
+            # Don't protect files when testing.
+            protect=not env.INTERACTIVE and not env.TESTING,
         )
 
     # Create a temporary VDB so that common packages needed for pkg_nofetch and pkg_pretend
@@ -323,23 +439,26 @@ def configure(
                 trans.pkg.FILE, os.path.join(env.TMP_VDB, "common", trans.pkg.PN)
             )
 
-    def print_restricted_fetch(transactions: Transactions):
+    def get_restricted_fetch(transactions: Transactions):
         # Check for restricted fetch packages and print their nofetch notices
+        restricted = 0
         for trans in transactions.pkgs:
             if not isinstance(trans, Delete):
-                can_fetch = fetchable(trans.pkg)
+                can_fetch = fetchable(trans.pkg, trans.flags)
+                sources = trans.pkg.get_sources(trans.flags)
                 to_fetch = [
-                    source
-                    for source in trans.pkg.get_default_sources()
-                    if find_download(source) is None
+                    source for source in sources if find_download(source) is None
                 ]
-                if set(to_fetch) - set(can_fetch) and not is_downloaded(trans.pkg):
+                if set(to_fetch) - set(can_fetch) and not is_downloaded(
+                    trans.pkg, trans.flags
+                ):
+                    restricted += len(set(to_fetch) - set(can_fetch))
                     print(
                         bright(yellow(l10n("fetch-instructions", atom=trans.pkg.ATOM)))
                     )
                     state = {
                         "UNFETCHED": to_fetch,
-                        "A": trans.pkg.get_default_sources(),
+                        "A": sources,
                         "USE": trans.pkg.get_use(),
                     }
                     _sandbox_execute_pybuild(
@@ -349,8 +468,9 @@ def configure(
                         init=state,
                     )
                     print()
+        return restricted
 
-    print_restricted_fetch(transactions)
+    restricted_downloads = get_restricted_fetch(transactions)
 
     tmp_dir = env.TMP_DIR
     # If TMP_DIR doesn't exist, either use the parent, or if that doesn't exist,
@@ -362,6 +482,7 @@ def configure(
             os.makedirs(tmp_dir, exist_ok=True)
     tmp_space = shutil.disk_usage(tmp_dir).free
 
+    pre_merge_warnings = 0
     for trans in transactions.pkgs:
         if not isinstance(trans, Delete) and "pkg_pretend" in trans.pkg.FUNCTIONS:
             info(">>> " + l10n("pkg-pretend", atom=green(trans.pkg.ATOM.CPF)))
@@ -371,15 +492,17 @@ def configure(
                 "pretend",
                 Permissions(),
                 save_state=True,
+                init={"USE": trans.flags},
             )
 
             total_size = 0
-            for source in trans.pkg.get_default_sources():
+            for source in trans.pkg.get_sources(trans.flags):
                 total_size += source.size
 
             # We assume that files have a compression ratio of approximately 0.5
             # Thus we want at least twice the size of the archives in free space.
             if total_size * 2 > tmp_space:
+                pre_merge_warnings += 1
                 warning(
                     l10n(
                         "tmp-space-too-small",
@@ -388,8 +511,30 @@ def configure(
                         size=total_size * 2 / 1024 / 1024,
                     )
                 )
+            pre_merge_warnings += len(
+                {message for typ, message in get_messages(trans.pkg) if typ == "warn"}
+            )
 
-    if not (no_confirm or prompt_bool(l10n("continue-qn"))):
+    if pre_merge_warnings:
+        warning(l10n("pre-merge-warnings", warnings=pre_merge_warnings))
+    if restricted_downloads and not env.INTERACTIVE:
+        error(l10n("exiting-non-interactive-nofetch"))
+        sys.exit(1)
+    elif restricted_downloads:
+        warning(l10n("restricted-fetch-summary", restricted=restricted_downloads))
+        # Loop until all restricted downloads are available
+        while restricted_downloads > 0:
+            if not prompt_bool(l10n("continue-qn")):
+                sys.exit(1)
+
+            new_restricted_downloads = get_restricted_fetch(transactions)
+            if new_restricted_downloads == 0:
+                break
+            if new_restricted_downloads >= restricted_downloads:
+                error(l10n("restricted-fetch-unchanged"))
+                sys.exit(1)
+            restricted_downloads = new_restricted_downloads
+    elif env.INTERACTIVE and not prompt_bool(l10n("continue-qn")):
         return
 
     err = None
@@ -420,21 +565,11 @@ def configure(
         clear_vfs_sort()
 
     for trans in merged.pkgs:
-        pkg = trans.pkg
-        warning_path = os.path.join(env.WARNINGS_DIR, pkg.ATOM.CPF)
-        info_path = os.path.join(env.MESSAGES_DIR, pkg.ATOM.CPF)
-        messages = []
-        if os.path.exists(warning_path):
-            with open(warning_path, "r") as file:
-                messages.append(("WARN", file.read()))
-
-        if os.path.exists(info_path):
-            with open(info_path, "r") as file:
-                messages.append(("INFO", file.read()))
+        messages = get_messages(trans.pkg)
 
         if messages:
             print()
-            print(">>> " + l10n("pkg-messages", atom=bright(green(pkg))))
+            print(">>> " + l10n("pkg-messages", atom=bright(green(trans.pkg))))
             for typ, msg in messages:
                 if typ == "WARN":
                     warning(msg)
@@ -449,36 +584,26 @@ def configure(
             else:
                 add_set("selected-sets", Atom(set_name))
 
-    # Commit changes to installed database
-    gitrepo = git.Repo.init(env.prefix().INSTALLED_DB)
-    try:
-        gitrepo.head.commit
-    except ValueError:
-        gitrepo.git.commit(m=l10n("initial-commit"))
-
     transstring = io.StringIO()
     print_transactions(merged, verbose=True, out=transstring, summarize=False)
-    if gitrepo.git.diff("HEAD", cached=True):
+    if err:
         # There was an error. We report the packages that were successfully merged and
         # note that an error occurred, however we still commit anyway.
-        if err:
-            gitrepo.git.commit(
-                m=(
-                    l10n(
-                        "merge-success-and-error", num=len(transactions.pkgs), atom=err
-                    )
-                    + "\n"
-                    + transstring.getvalue()
-                )
-            )
-        else:
-            gitrepo.git.commit(
-                m=(
-                    l10n("merge-success", num=len(transactions.pkgs))
-                    + "\n"
-                    + transstring.getvalue()
-                )
-            )
+        message = (
+            l10n("merge-success-and-error", num=len(transactions.pkgs), atom=err)
+            + "\n"
+            + transstring.getvalue()
+        )
+    else:
+        message = (
+            l10n("merge-success", num=len(transactions.pkgs))
+            + "\n"
+            + transstring.getvalue()
+        )
+
+    # Commit changes to installed database
+    with VDB(message):
+        pass
 
     # Check if packages were just modified and can be removed from the rebuild set
     # Any transaction type warrants removal, as they were either rebuilt,
