@@ -14,10 +14,10 @@ specific versions or ranges of versions.
 
 import os
 import re
-from functools import lru_cache
 from logging import info
 from typing import Iterable, Optional, Set
 
+from portmod.functools import system_cache
 from portmodlib.atom import Atom, atom_sat
 from portmodlib.l10n import l10n
 from portmodlib.parsers.list import read_list
@@ -138,7 +138,7 @@ def remove_flag(file: str, atom: Atom, flag: str):
     __write_flags(file, flagfile)
 
 
-@lru_cache()
+@system_cache
 def __read_flags(file):
     if os.path.exists(file):
         with open(file, mode="r") as flagfile:
