@@ -118,13 +118,6 @@ class Pybuild(BasePybuild):
         )
         return parse_arrow(sources)
 
-    def get_default_sources(self) -> List[SourceManifest]:
-        """
-        Returns a list of sources that are enabled
-        with the current use configuration
-        """
-        return self.get_sources(self.get_use())
-
     def get_sources(
         self,
         uselist: AbstractSet[str] = frozenset(),
@@ -184,7 +177,7 @@ class Pybuild(BasePybuild):
         return self.parse_string(self.PROPERTIES, matchall=matchall)
 
     def get_default_source_basename(self) -> Optional[str]:
-        tmp_source = next(iter(self.get_default_sources()), None)
+        tmp_source = next(iter(self.get_sources(self.get_use())), None)
         if tmp_source:
             return get_archive_basename(tmp_source.name)
         return None
@@ -236,9 +229,14 @@ class Pybuild(BasePybuild):
                 "PROPERTIES must be a string containing a space separated list"
             )
 
-        IUSE_STRIP = {use.lstrip("+") for use in self.IUSE}
+        iuse_strip = {use.lstrip("+") for use in self.IUSE}
         errors = []
 
+        if not self.REPO_PATH:
+            raise RuntimeError(
+                "Pybuild.validate called on a pybuild which doesn't have a repository!"
+            )
+
         def check_use_reduce(attr: str, *, is_src_uri: bool = False, token_class=str):
             try:
                 return use_reduce(
@@ -251,6 +249,7 @@ class Pybuild(BasePybuild):
                 )
             except UseParserError as error:
                 errors.append(f"Failed to parse {attr}: {error}")
+            return []
 
         rdeps = check_use_reduce("RDEPEND", token_class=Atom)
         deps = check_use_reduce("DEPEND", token_class=Atom)
@@ -323,7 +322,7 @@ class Pybuild(BasePybuild):
         global_use = get_global_use(self.REPO_PATH)
         metadata = get_package_metadata(self)
 
-        for use in IUSE_STRIP:
+        for use in iuse_strip:
             if global_use.get(use) is None and (
                 metadata is None
                 or metadata.use is None
@@ -342,8 +341,8 @@ class Pybuild(BasePybuild):
 
                 if not valid:
                     errors.append(
-                        'Use flag "{}" must be either a global use flag '
-                        "or declared in metadata.yaml".format(use)
+                        f'Use flag "{use}" must be either a global use flag '
+                        "or declared in metadata.yaml"
                     )
 
         for value in self.get_restrict(matchall=True):
@@ -363,14 +362,12 @@ class Pybuild(BasePybuild):
             if isinstance(install, InstallDir):
                 if len(all_sources) > 0 and install.S is None:
                     if len(all_sources) != 1:
-                        raise Exception(
+                        errors.append(
                             "InstallDir does not declare a source name but source "
                             "cannot be set automatically"
                         )
             else:
-                raise TypeError(
-                    "InstallDir {} should be of type InstallDir".format(install)
-                )
+                errors.append(f"InstallDir {install} should be of type InstallDir")
 
         manifest = self.get_manifest()
         for source in self._get_sources(matchall=True):
@@ -461,6 +458,7 @@ def to_cache(pkg: FullPybuild) -> Dict:
         "DEPEND",
         "SRC_URI",
         "REQUIRED_USE",
+        "REQUIRED_USE_EFFECTIVE",
         "RESTRICT",
         "PROPERTIES",
         "IUSE_EFFECTIVE",
