@@ -5,27 +5,35 @@
 Module for performing bulk queries on the mod database and repositories
 """
 
+import json
 import logging
+import os
 import re
+import shutil
 import sys
 from collections import defaultdict
-from collections.abc import Container
+from functools import cmp_to_key
+from logging import info
+from time import sleep
+from types import SimpleNamespace
 from typing import (
     AbstractSet,
     Any,
     DefaultDict,
     Dict,
-    Generator,
     Iterable,
     List,
     Optional,
+    Sequence,
     Tuple,
     Union,
 )
 
-from portmodlib.atom import Atom, FQAtom, atom_sat
+from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat, version_gt
 from portmodlib.colour import blue, bright, cyan, green, lblue, lgreen, red, yellow
 from portmodlib.l10n import l10n
+from portmodlib.portmod import query as native_query
+from portmodlib.portmod import update_index as native_update_index
 from portmodlib.usestr import parse_usestr
 
 from .config import get_config
@@ -34,12 +42,35 @@ from .config.use import get_use, get_use_expand, use_reduce
 from .download import get_total_download_size
 from .globals import env
 from .loader import load_all, load_all_installed, load_installed_pkg, load_pkg
+from .prefix import get_prefixes
 from .pybuild import Pybuild
 from .repo import get_repo
-from .repo.metadata import get_global_use, get_package_metadata, get_use_expand_values
+from .repo.metadata import get_global_use
+from .repo.metadata import get_package_metadata as get_native_metadata
+from .repo.metadata import get_use_expand_values
 from .util import get_newest, sort_by_version
 
 
+class PackageMetadata(SimpleNamespace):
+    """Data class for package metadata returned by query results"""
+
+    cpn: str
+    prefix: str
+    category: str
+    package: str
+    name: str
+    desc: str
+    homepage: Optional[str] = None
+    other_homepages: Optional[str] = None
+    license: Optional[str] = None
+    longdescription: Optional[str] = None
+    maintainer: Optional[str] = None
+    upstream_maintainer: Optional[str] = None
+    upstream_doc: Optional[str] = None
+    upstream_bugs_to: Optional[str] = None
+    upstream_changelog: Optional[str] = None
+
+
 def get_maintainer_string(maintainers: Union[List[Any], Any]) -> str:
     def list_maintainers_to_human_strings(maintainers: List[Any]) -> str:
         """return the list of maintainers as a human readible string"""
@@ -131,50 +162,28 @@ def str_squelch_sep(value: str) -> str:
 
 
 def query(
-    fields: Union[str, Iterable],
     value: str,
-    strip: bool = False,
-    squelch_sep: bool = False,
-    insensitive: bool = False,
-    installed: bool = False,
-) -> Generator[Pybuild, None, None]:
+    limit: int = 10,
+) -> List[PackageMetadata]:
     """
     Finds mods that contain the given value in the given field
     """
+    results = []
+    if not env.PREFIX_NAME:
+        raise RuntimeError("Queries must be done inside a prefix!")
+    for result in native_query(env.INDEX, env.PREFIX_NAME, value, limit):
+        data = json.loads(result)
+        # Results from tantivy are all lists?
+        metadata = {}
+        for key, value in data.items():
+            metadata[key] = value[0]
+        results.append(PackageMetadata(**metadata))
 
-    def func(val: str) -> str:
-        result = val
-        if insensitive:
-            result = result.lower()
-        if strip:
-            result = str_strip(result)
-        if squelch_sep:
-            result = str_squelch_sep(result)
-        return result
-
-    search = func(value)
-
-    if not installed:
-        mods = load_all()
-    else:
-        mods = load_all_installed()
-
-    for mod in mods:
-        if isinstance(fields, str):
-            if (
-                hasattr(mod, fields)
-                and isinstance(getattr(mod, fields), Container)
-                and search in func(getattr(mod, fields))
-            ):
-                yield mod
-        else:
-            if any(
-                hasattr(mod, field) and search in func(getattr(mod, field))
-                for field in fields
-            ):
-                yield mod
+    return results
 
 
+# FIXME: For this to be indexed, we'll need to add DEPEND and RDEPEND to the index
+# This also means indexing individual package versions as well as aggregated data
 def query_depends(atom: Atom, all_mods=False) -> List[Tuple[FQAtom, str]]:
     """
     Finds mods that depend on the given atom
@@ -189,10 +198,19 @@ def query_depends(atom: Atom, all_mods=False) -> List[Tuple[FQAtom, str]]:
         if not all_mods:
             enabled, disabled = get_use(mod)
             atoms = use_reduce(
-                mod.RDEPEND, enabled, disabled, token_class=Atom, flat=True
+                mod.RDEPEND + " " + mod.DEPEND,
+                enabled,
+                disabled,
+                token_class=Atom,
+                flat=True,
             )
         else:
-            atoms = use_reduce(mod.RDEPEND, token_class=Atom, matchall=True, flat=True)
+            atoms = use_reduce(
+                mod.RDEPEND + " " + mod.DEPEND,
+                token_class=Atom,
+                matchall=True,
+                flat=True,
+            )
 
         for dep_atom in atoms:
             if dep_atom != "||" and atom_sat(dep_atom, atom):
@@ -252,20 +270,21 @@ def get_flag_string(
 
 
 def display_search_results(
-    package_groups: List[List[Pybuild]],
+    packages: Sequence[PackageMetadata],
     summarize: bool = True,
     numbers: bool = False,
     file=sys.stdout,
 ):
     """
-    Prettily formats a list of mods for use in search results
+    Prettily formats a list of package metadata for use in search results
     """
     count = 0
-    for group in package_groups:
+    for package in packages:
         count += 1
+        group = load_pkg(Atom(package.cpn))
         sortedmods = sort_by_version(group)
         newest = get_newest(group)
-        installed = load_installed_pkg(Atom(newest.CPN))
+        installed = load_installed_pkg(Atom(package.cpn))
         download = get_total_download_size([newest])
 
         if installed is not None:
@@ -372,15 +391,23 @@ def display_search_results(
 
         # If there are multiple URLs, remove any formatting from the pybuild and
         # add padding
-        homepage_str = "\n                 ".join(newest.HOMEPAGE.split())
-        mod_metadata = get_package_metadata(mod)
 
         if logging.root.level <= logging.DEBUG:
+            if package.homepage:
+                formatted_homepages = "\n                 ".join(
+                    [package.homepage] + (package.other_homepages or "").split()
+                )
+
+                homepage_str = (
+                    "       {} {}".format(
+                        green(l10n("package-homepage")), formatted_homepages
+                    ),
+                )
             print(
                 "{} {}  {}".format(
-                    cyan(count) if numbers else "", green("*"), bright(newest.CPN)
+                    cyan(count) if numbers else "", green("*"), bright(package.cpn)
                 ),
-                "       {} {}".format(green(l10n("package-name")), mod.NAME),
+                "       {} {}".format(green(l10n("package-name")), package.name),
                 "       {} {}".format(
                     green(l10n("package-available-versions")), version_str
                 ),
@@ -388,30 +415,32 @@ def display_search_results(
                     green(l10n("package-installed-version")), installed_str
                 ),
                 "       {} {}".format(green(l10n("package-size-of-files")), download),
-                "       {} {}".format(green(l10n("package-homepage")), homepage_str),
+                sep=os.linesep,
+                file=file,
+            )
+            if package.homepage:
+                print(homepage_str, file=file)
+            print(
                 "       {} {}".format(
                     green(l10n("package-description")), str_squelch_sep(newest.DESC)
                 ),
                 "       {} {}".format(green(l10n("package-license")), newest.LICENSE),
-                sep="\n",
+                sep=os.linesep,
                 file=file,
             )
-            if mod_metadata and mod_metadata.upstream:
-                maintainers = mod_metadata.upstream.maintainer
-                if maintainers:
-                    maintainers_display_strings = get_maintainer_string(maintainers)
-                    print(
-                        "       {} {}".format(
-                            green(l10n("package-upstream-author")),
-                            maintainers_display_strings,
-                        ),
-                        file=file,
-                    )
+            if package.upstream_maintainer:
+                print(
+                    "       {} {}".format(
+                        green(l10n("package-upstream-author")),
+                        package.upstream_maintainer,
+                    ),
+                    file=file,
+                )
             print(file=file)
         else:
             print(
                 "{} {}  {}".format(
-                    cyan(count) if numbers else "", green("*"), bright(newest.CPN)
+                    cyan(count) if numbers else "", green("*"), bright(package.cpn)
                 ),
                 "       {} {}".format(
                     green(l10n("package-available-versions")), version_str
@@ -419,16 +448,26 @@ def display_search_results(
                 "       {} {}".format(
                     green(l10n("package-installed-version")), installed_str
                 ),
-                "       {} {}".format(green(l10n("package-homepage")), homepage_str),
+                sep=os.linesep,
+                file=file,
+            )
+            if package.homepage:
+                print(
+                    "       {} {}".format(
+                        green(l10n("package-homepage")), package.homepage
+                    ),
+                    file=file,
+                )
+            print(
                 "       {} {}".format(
                     green(l10n("package-description")), str_squelch_sep(newest.DESC)
                 ),
-                sep="\n",
+                sep=os.linesep,
                 file=file,
             )
 
     if summarize:
-        print("\n" + l10n("packages-found", num=len(package_groups)), file=file)
+        print("\n" + l10n("packages-found", num=len(packages)), file=file)
 
 
 class FlagDesc:
@@ -469,7 +508,7 @@ def get_flag_desc(pkg: Pybuild, flag: str) -> Optional[FlagDesc]:
     repo_root = get_repo(pkg.REPO).location
 
     global_use = get_global_use(repo_root)
-    metadata = get_package_metadata(pkg)
+    metadata = get_native_metadata(pkg)
 
     if metadata and flag in metadata.use:
         return LocalFlagDesc(pkg, metadata.use[flag])
@@ -501,7 +540,7 @@ def get_flags(
     repo_root = get_repo(pkg.REPO).location
 
     global_use = get_global_use(repo_root)
-    metadata = get_package_metadata(pkg)
+    metadata = get_native_metadata(pkg)
 
     local_flags = {}
     global_flags = {}
@@ -528,3 +567,182 @@ def get_flags(
             continue
 
     return local_flags, global_flags, use_expand_flags
+
+
+def get_package_metadata(package: QualifiedAtom) -> Optional[PackageMetadata]:
+    packages = load_pkg(package)
+    if not packages:
+        return None
+
+    def version_cmp(x, y):
+        if version_gt(x.PVR, y.PVR):
+            return -1
+        else:
+            return 1
+
+    pkgs = sorted(packages, key=cmp_to_key(version_cmp))
+    newest = pkgs[-1]
+
+    pkg_metadata = PackageMetadata(
+        cpn=package.CPN,
+        prefix=env.PREFIX_NAME,
+        category=package.C,
+        package=package.PN,
+        name=newest.NAME,
+        desc=newest.DESC,
+    )
+
+    homepages = use_reduce(newest.HOMEPAGE, matchall=True, flat=True)
+
+    if homepages:
+        pkg_metadata.homepage = homepages[0]
+    if len(homepages) > 1:
+        pkg_metadata.other_homepages = " ".join(homepages[1:])
+
+    if newest.LICENSE:
+        pkg_metadata.license = newest.LICENSE
+
+    for pkg in pkgs:
+        metadata = get_native_metadata(pkg)
+        if metadata:
+            if metadata.longdescription:
+                pkg_metadata.longdescription = metadata.longdescription
+            if metadata.maintainer:
+                pkg_metadata.maintainer = get_maintainer_string(metadata.maintainer)
+            if metadata.upstream:
+                if metadata.upstream.maintainer:
+                    pkg_metadata.upstream_maintainer = get_maintainer_string(
+                        metadata.upstream.maintainer
+                    )
+                if metadata.upstream.doc:
+                    pkg_metadata.upstream_doc = metadata.upstream.doc
+                if metadata.upstream.bugs_to:
+                    pkg_metadata.upstream_bugs_to = metadata.upstream.bugs_to
+                if metadata.upstream.changelog:
+                    pkg_metadata.upstream_changelog = metadata.upstream.changelog
+
+    return pkg_metadata
+
+
+def _get_index_data() -> List[PackageMetadata]:
+    if not env.PREFIX_NAME:
+        return []
+
+    def get_package_names():
+        seen = set()
+        for pkg in load_all():
+            if pkg.CPN not in seen:
+                seen.add(pkg.CPN)
+                yield pkg.CPN
+        for pkg in load_all_installed():
+            if pkg.CPN not in seen:
+                seen.add(pkg.CPN)
+                yield pkg.CPN
+
+    info("Beginning index update for prefix " + env.PREFIX_NAME)
+    if sys.stderr.isatty():
+        try:
+            from progressbar import GranularBar as Bar
+        except ImportError:
+            from progressbar import Bar
+        from progressbar import ETA, BouncingBar, Counter, ProgressBar, Timer, Variable
+
+        package_names = set()
+        bar = ProgressBar(
+            redirect_stdout=True,
+            widgets=[
+                Variable("status", format="Collecting packages"),
+                BouncingBar(),
+                Counter(),
+                " ",
+                Timer(),
+            ],
+        )
+
+        i = 0
+        bar.start()
+        for name in get_package_names():
+            package_names.add(name)
+            bar.update(i)
+            i += 1
+        bar.finish()
+
+        package_data = []
+        bar = ProgressBar(
+            redirect_stdout=True,
+            widgets=[
+                Variable("status", format="Loading package data"),
+                Bar(),
+                Counter(),
+                " ",
+                ETA(),
+            ],
+            max_value=len(package_names),
+        )
+        bar.start()
+        i = 0
+        for cpn in package_names:
+            metadata = get_package_metadata(cpn)
+            if metadata:
+                package_data.append(metadata)
+            bar.update(i)
+            i += 1
+        bar.finish()
+    else:
+        package_data = []
+        for name in get_package_names():
+            metadata = get_package_metadata(name)
+            if metadata:
+                package_data.append(metadata)
+    return package_data
+
+
+def _commit_index(package_data: List[PackageMetadata]):
+    from multiprocessing import Process
+
+    from progressbar import AnimatedMarker, ProgressBar, UnknownLength, Variable
+
+    os.makedirs(env.INDEX, exist_ok=True)
+
+    if sys.stderr.isatty():
+        bar = ProgressBar(
+            widgets=[
+                Variable("status", format="{variables.status}"),
+                " ",
+                AnimatedMarker(),
+            ],
+            max_value=UnknownLength,
+            variables={"status": "Updating index"},
+        )
+        bar.start()
+
+        process = Process(
+            target=native_update_index,
+            args=(env.INDEX, [pkg.__dict__ for pkg in package_data]),
+        )
+        process.start()
+        while process.is_alive():
+            bar.update()
+            sleep(0.1)
+
+        bar.update(status="Done updating index.")
+        bar.finish()
+    else:
+        info("Updating index...")
+        native_update_index(env.INDEX, [pkg.__dict__ for pkg in package_data])
+        info("Done updating index.")
+
+
+def update_index():
+    orig_prefix = env.PREFIX_NAME
+    if os.path.exists(env.INDEX):
+        shutil.rmtree(env.INDEX)
+    package_data = []
+    if env.TESTING:
+        package_data.extend(_get_index_data())
+    else:
+        for prefix in get_prefixes():
+            env.set_prefix(prefix)
+            package_data.extend(_get_index_data())
+    _commit_index(package_data)
+    env.set_prefix(orig_prefix)
