@@ -10,20 +10,19 @@ See portmod.loader for functions to load pybuilds safely using a sandbox.
 import glob
 import os
 from copy import deepcopy
-from functools import lru_cache
 from logging import warning
 from types import SimpleNamespace
 from typing import Callable, Dict, Generator, Optional, cast
 
 from portmod.config.mask import is_masked
-from portmod.functools import install_cache
+from portmod.functools import install_cache, prefix_aware_cache, system_cache
 from portmod.globals import env
 from portmod.lock import vdb_lock
 from portmod.parsers.manifest import Manifest
 from portmod.repo import Repo, get_repo, get_repo_name
 from portmod.repo.metadata import get_categories, get_masters
 from portmod.util import get_max_version
-from portmod.vdb import VDB
+from portmod.vdb import VDB, vdb_path
 from portmodlib._loader import (
     SAFE_GLOBALS,
     __load_file_common,
@@ -49,12 +48,10 @@ def commit_moved():
         for source, dest in moved.items():
             atom = QualifiedAtom(source)
 
-            path = os.path.join(env.prefix().INSTALLED_DB, atom.C, atom.PN)
+            path = os.path.join(vdb_path(), atom.C, atom.PN)
             if os.path.exists(path):
                 destatom = QualifiedAtom(dest)
-                destpath = os.path.join(
-                    env.prefix().INSTALLED_DB, destatom.C, destatom.PN
-                )
+                destpath = os.path.join(vdb_path(), destatom.C, destatom.PN)
                 for filepath in glob.glob(os.path.join(path, "*.pybuild")):
                     oldatom = get_atom_from_path(filepath)
                     if oldatom.R != repo.name:
@@ -66,7 +63,7 @@ def commit_moved():
 
 
 def find_installed_path(atom: Atom) -> Optional[str]:
-    repo_path = env.prefix().INSTALLED_DB
+    repo_path = vdb_path()
 
     # Handle renames:
     # Check all possible renames for this atom (all repos), and they are only valid if
@@ -98,6 +95,20 @@ def find_installed_path(atom: Atom) -> Optional[str]:
     return None
 
 
+# Make sure this is only run once since _iterate_pybuilds is called many times
+@system_cache
+def check_repo_exists(name: str, location: str):
+    if not os.path.exists(location):
+        warning(
+            l10n(
+                "repo-does-not-exist-warning",
+                name=name,
+                path=location,
+                command="portmod sync",
+            )
+        )
+
+
 def _iterate_pybuilds(
     atom: Optional[Atom] = None,
     repo_name: Optional[str] = None,
@@ -141,23 +152,14 @@ def _iterate_pybuilds(
         return true_atom
 
     for repo in repos:
-        if not os.path.exists(repo.location):
-            warning(
-                l10n(
-                    "repo-does-not-exist-warning",
-                    name=repo.name,
-                    path=repo.location,
-                    command="omwmerge --sync",
-                )
-            )
-
+        check_repo_exists(repo.name, repo.location)
         if atom:
             moved = get_moved(repo)
             if atom.C:
                 true_atom = try_move_atom(moved, cast(QualifiedAtom, atom), repo)
                 path = os.path.join(repo.location, true_atom.C, true_atom.PN)
-                if path is not None and os.path.exists(path):
-                    for file in glob.glob(os.path.join(path, "*.pybuild")):
+                if path is not None:
+                    for file in glob.iglob(os.path.join(path, "*.pybuild")):
                         if valid_atom(true_atom, get_atom_from_path(file)):
                             yield file
             else:
@@ -165,16 +167,16 @@ def _iterate_pybuilds(
                     true_atom = try_move_atom(moved, atom.with_category(category), repo)
                     path = os.path.join(repo.location, category, true_atom.PN)
 
-                    if path is not None and os.path.exists(path):
-                        for file in glob.glob(os.path.join(path, "*.pybuild")):
+                    if path is not None:
+                        for file in glob.iglob(os.path.join(path, "*.pybuild")):
                             if valid_atom(true_atom, get_atom_from_path(file)):
                                 yield file
         else:
-            for file in glob.glob(os.path.join(repo.location, "*", "*", "*.pybuild")):
+            for file in glob.iglob(os.path.join(repo.location, "*", "*", "*.pybuild")):
                 yield file
 
 
-@lru_cache()
+@system_cache
 def _import_common(
     name: str,
     installed: bool,
@@ -246,6 +248,7 @@ def __safe_load_file(path: str, *, installed=False) -> FullPybuild:
     return cast(FullPybuild, pkg)
 
 
+@prefix_aware_cache
 def pkg_exists(atom: Atom, *, repo_name: Optional[str] = None) -> bool:
     """Returns true if a package with the given atom can be found in the given repository"""
     return next(_iterate_pybuilds(atom, repo_name), None) is not None
@@ -360,9 +363,7 @@ def __safe_load_module(path: str, installed: bool, repo: Optional[str]):
 
 
 def _iterate_installed() -> Generator[str, None, None]:
-    repo = env.prefix().INSTALLED_DB
-
-    for path in glob.glob(os.path.join(repo, "*", "*", "*.pybuild")):
+    for path in glob.glob(os.path.join(vdb_path(), "*", "*", "*.pybuild")):
         yield path
 
 
