@@ -3,8 +3,18 @@
 
 import re
 import sys
-from collections import defaultdict
-from typing import AbstractSet, Any, Callable, Dict, Iterable, List, Optional, Set, cast
+from typing import (
+    AbstractSet,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    cast,
+)
 
 from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat, version_gt
 from portmodlib.colour import blue, bright, green, lgreen, red, yellow
@@ -14,7 +24,7 @@ from portmodlib.usestr import use_reduce
 from .config import get_config
 from .config.sets import is_selected
 from .config.use import get_use, get_use_expand
-from .download import get_download_size
+from .download import fetchable, find_download, get_download_size
 from .loader import (
     SandboxedError,
     _sandbox_execute_pybuild,
@@ -138,10 +148,13 @@ class Transactions:
 
 
 class UseDep:
-    def __init__(self, atom: FQAtom, flag: str, oldvalue: Optional[str]):
+    def __init__(
+        self, atom: FQAtom, flag: str, oldvalue: Optional[str], comment: Sequence[str]
+    ):
         self.atom = atom
         self.flag = flag
         self.oldvalue = oldvalue
+        self.comment = comment
 
     def __repr__(self):
         if self.oldvalue:
@@ -246,7 +259,7 @@ def print_transactions(
 ):
     pkgs = transactions.pkgs
     download_size = get_download_size(
-        [trans.pkg for trans in pkgs if not isinstance(trans, Delete)]
+        {trans.pkg: trans.flags for trans in pkgs if not isinstance(trans, Delete)}
     )
 
     for trans in pkgs:
@@ -281,10 +294,22 @@ def print_transactions(
         else:
             modstring = green(modstring)
 
+        fetch_status = " "
+        fetchable_files = set(fetchable(trans.pkg, trans.flags))
+        fetch_restricted = [
+            source
+            for source in trans.pkg.get_sources(trans.flags)
+            if source not in fetchable_files
+        ]
+        if fetch_restricted:
+            if all(find_download(source) for source in fetch_restricted):
+                fetch_status = "f"
+            else:
+                fetch_status = "F"
+
         print(
-            "[{}] {}{}{}".format(
-                bright(trans_colour(trans.REPR)), modstring, oldver, " " + usestring
-            ),
+            f"[{red(fetch_status)}{bright(trans_colour(trans.REPR))}]"
+            f" {modstring}{oldver} {usestring}",
             file=out,
         )
 
@@ -394,8 +419,8 @@ def generate_transactions(
     disabled: Iterable[FQAtom],
     newselected: AbstractSet[QualifiedAtom],
     usedeps: Iterable[UseDep],
+    enabled_flags: Dict[FQAtom, Set[str]],
     *,
-    noreplace: bool = False,
     emptytree: bool = False,
     update: bool = False,
 ) -> Transactions:
@@ -404,26 +429,22 @@ def generate_transactions(
     all packages in enabled are installed and all packages in disabled are not
 
     Packages will not be rebuilt unless a change has occurred, or they are included
-    in the new_selected parameter set and noreplace is not specified.
+    in the new_selected parameter set and update is not specified.
 
     args:
         enabled: Packages that should be enabled, if not already
         disabled: Packages that should be disabled, if not already
         new_selected: Packages that were selected by the user for this operation
                       These should be re-installed, even if no change has been
-                      made, unless noreplace is also passed
+                      made, unless update is also passed
         usedeps: Use changes that should accompany the transactions
-        noreplace: If true, don't re-install selected packages that haven't changed
-        update: If true, will update live packages
+        update: If true, will update live packages, and won't re-install packages which haven't changed
 
     returns:
         Onject representing the transactions
     """
 
     transactions = Transactions()
-    flagupdates: Dict[str, Set[str]] = defaultdict(set)
-    for dep in usedeps:
-        flagupdates[dep.atom].add(dep.flag)
 
     # Note: while this technically requires knowing about the use flags in advance,
     # despite being needed to determine the use flags enabled, any flags which are related
@@ -431,7 +452,7 @@ def generate_transactions(
     # the dependency calculator.
     def is_installed(atom: Atom) -> bool:
         for fqatom in enabled:
-            if atom_sat(fqatom, atom) and atom.USE <= flagupdates[fqatom]:
+            if atom_sat(fqatom, atom) and atom.USE <= enabled_flags[fqatom]:
                 return True
         return False
 
@@ -442,7 +463,7 @@ def generate_transactions(
             filter(
                 lambda x: not x.startswith("-"),
                 collapse_flags(
-                    get_use(pkg, is_installed=is_installed)[0], flagupdates[atom]
+                    get_use(pkg, is_installed=is_installed)[0], enabled_flags[atom]
                 ),
             )
         )
@@ -453,7 +474,10 @@ def generate_transactions(
         (to_install, dep) = select_package([pkg])
 
         if dep is not None:
-            transactions.config.add(dep)
+            if isinstance(dep, (list, set)):
+                transactions.config |= set(dep)
+            else:
+                transactions.config.add(dep)
 
         installed = load_installed_pkg(Atom(atom.CPN))
 
@@ -501,7 +525,7 @@ def generate_transactions(
                 transactions.append(Update(to_install or installed, installed, flags))
             elif installed.INSTALLED_USE != flags:
                 transactions.append(Reinstall(to_install or installed, flags))
-            elif not noreplace and installed.ATOM.CPN in newselected:
+            elif not update and installed.ATOM.CPN in newselected:
                 transactions.append(Reinstall(to_install or installed, flags))
             elif to_install and not atom.R.endswith("::installed"):
                 # If the repo's version is enabled, this means the dep generator
@@ -516,19 +540,9 @@ def generate_transactions(
         if to_remove is not None:
             transactions.append(Delete(to_remove))
 
-    # Only add usedeps that differ from their current setting
-    # for the mod to be installed
     for dep in usedeps:
         for trans in transactions.pkgs:
             if atom_sat(trans.pkg.ATOM, dep.atom):
-                enabled_use, _ = get_use(trans.pkg, is_installed=is_installed)
-                if (
-                    dep.flag[0] == "-"
-                    and dep.flag.lstrip("-") in enabled_use
-                    or dep.flag[0] != "-"
-                    and dep.flag not in enabled_use
-                ):
-
-                    transactions.config.add(dep)
+                transactions.config.add(dep)
 
     return transactions
