@@ -17,7 +17,7 @@ from .globals import env
 from .pybuild import Pybuild
 
 KeywordDep = namedtuple("KeywordDep", ["atom", "keyword", "masked"])
-LicenseDep = namedtuple("LicenseDep", ["atom", "license", "is_eula"])
+LicenseDep = namedtuple("LicenseDep", ["atom", "license", "is_eula", "repo"])
 
 
 def is_keyword_masked(arch: str, keywords: Iterable[str]):
@@ -70,19 +70,19 @@ def select_package(packages: Iterable[Pybuild]) -> Tuple[Pybuild, Any]:
             mod = get_newest(packages)
             keyword = "**"
 
-    if not is_license_accepted(mod):
-        return (mod, LicenseDep(mod.CPN, mod.LICENSE, has_eula(mod)))
+    deps: List[Any] = []
+    if not is_license_accepted(mod, mod.get_use()):
+        deps.append(LicenseDep(mod.CPN, mod.LICENSE, has_eula(mod), mod.REPO))
     if keyword is not None:
-        return (
-            mod,
+        deps.append(
             KeywordDep(
                 QualifiedAtom("=" + mod.ATOM.CPF),
                 keyword,
                 is_keyword_masked(env.prefix().ARCH, mod.KEYWORDS),
-            ),
+            )
         )
 
-    return (mod, None)
+    return (mod, deps or None)
 
 
 def get_max_version(versions: Iterable[str]) -> Optional[str]:
