@@ -11,7 +11,7 @@ from logging import error, info, warning
 from tempfile import gettempdir
 from typing import Dict, List, Set, Tuple
 
-from portmod.config import get_config
+from portmod.config import get_config_value, variable_data_dir
 from portmodlib.archives import extract_archive_file
 from portmodlib.atom import Atom, atom_sat
 from portmodlib.functools import clear_vfs_cache
@@ -80,35 +80,31 @@ def extract_archive_file_to_tmp(archive: str, file: str) -> str:
 
 def __set_vfs_dirs__(dirs: List[str]):
     """Updates the vfs directories"""
-    write_list(os.path.join(env.prefix().VARIABLE_DATA, "vfs"), dirs)
+    write_list(os.path.join(variable_data_dir(), "vfs"), dirs)
 
 
 def __set_vfs_archives(archives: List[str]):
     """Updates the vfs directories"""
-    write_list(os.path.join(env.prefix().VARIABLE_DATA, "vfs-archives"), archives)
+    write_list(os.path.join(variable_data_dir(), "vfs-archives"), archives)
 
 
 def require_vfs_sort():
     """
     Creates a file that indicates the vfs still needs to be sorted
     """
-    open(
-        os.path.join(env.prefix().VARIABLE_DATA, ".vfs_sorting_incomplete"), "a"
-    ).close()
+    open(os.path.join(variable_data_dir(), ".vfs_sorting_incomplete"), "a").close()
 
 
 def clear_vfs_sort():
     """Clears the file indicating the config needs sorting"""
-    path = os.path.join(env.prefix().VARIABLE_DATA, ".vfs_sorting_incomplete")
+    path = os.path.join(variable_data_dir(), ".vfs_sorting_incomplete")
     if os.path.exists(path):
         os.remove(path)
 
 
 def vfs_needs_sorting():
     """Returns true if changes have been made since the config was sorted"""
-    return os.path.exists(
-        os.path.join(env.prefix().VARIABLE_DATA, ".vfs_sorting_incomplete")
-    )
+    return os.path.exists(os.path.join(variable_data_dir(), ".vfs_sorting_incomplete"))
 
 
 def sort_vfs():
@@ -116,7 +112,7 @@ def sort_vfs():
     # The VFS setting is both the default state of InstallDirs, and enables the VFS as a whole.
     # If it is set, we assume that any InstallDirs which don't include the VFS option are part of
     # the VFS
-    if get_config().get("VFS"):
+    if get_config_value("VFS"):
         info(l10n("sorting-vfs"))
         _sort_vfs_dirs()
         _sort_vfs_archives()
