@@ -315,7 +315,7 @@ def __load_file_common(path: str, module: Dict[str, Any], installed: bool):
             # TODO: Inline imports in functions?
             return depends
 
-        pkg.RDEPEND = " ".join([pkg.RDEPEND] + find_common_imports(pkg.FILE))
+        pkg.DEPEND = " ".join([pkg.DEPEND] + find_common_imports(pkg.FILE))
     return pkg
 
 
@@ -361,3 +361,4 @@ def __load_installed_common(mod, file: str):
     mod.REPO = repo
     mod.INSTALLED_USE = set((read_file("USE") or "").split())
     mod.RDEPEND = read_file("RDEPEND") or mod.RDEPEND
+    mod.DEPEND = read_file("DEPEND") or mod.DEPEND
