@@ -289,6 +289,7 @@ class BasePybuild:
     CPN: QualifiedAtom
     CP: QualifiedAtom
     REQUIRED_USE: str = ""
+    REQUIRED_USE_EFFECTIVE: str = ""
     RESTRICT: str = ""
     PROPERTIES: str = ""
     IUSE_EFFECTIVE: Set[str] = set()
@@ -441,11 +442,17 @@ class FullPybuild(BasePybuild):
         elif type(self.TIER) is not str:
             raise TypeError("TIER must be a integer or string containing 0-9 or z")
 
+        self.REQUIRED_USE_EFFECTIVE: str = self.REQUIRED_USE
         if type(self.TEXTURE_SIZES) is str:
             texture_sizes = use_reduce(self.TEXTURE_SIZES, matchall=True)
-            self.IUSE_EFFECTIVE |= set(
-                ["texture_size_{}".format(size) for size in texture_sizes]
-            )
+            texture_size_flags = [
+                "texture_size_{}".format(size) for size in texture_sizes
+            ]
+            self.IUSE_EFFECTIVE |= set(texture_size_flags)
+            if texture_size_flags:
+                self.REQUIRED_USE_EFFECTIVE += (
+                    " ^^ ( " + " ".join(texture_size_flags) + " )"
+                )
         else:
             raise TypeError(
                 "TEXTURE_SIZES must be a string containing a space separated list of "
