@@ -6,13 +6,15 @@
 import logging
 import os
 import shutil
+from filecmp import cmp
 from glob import iglob
 from logging import info, warning
 from typing import Callable, Iterable, List, Optional, Pattern, Set, Tuple, Union, cast
 
 from portmodlib.atom import Atom
 from portmodlib.colour import blue, magenta
-from portmodlib.fs import is_parent, patch_dir
+from portmodlib.execute import execute
+from portmodlib.fs import ci_exists, is_parent, make_unique_filename, patch_dir
 from portmodlib.globals import messages_dir, warnings_dir
 from portmodlib.l10n import l10n
 from portmodlib.pybuild import FullPybuild, InstallDir, get_installed_env
@@ -38,10 +40,8 @@ def apply_patch(patch: str):
     args:
         patch: Path to the patch to be applied
     """
-    from git import Git
-
     print(l10n("applying-patch", patch=patch))
-    print(Git().apply([patch, "--stat", "--apply"]))
+    execute(["git", "apply", patch, "--stat", "--apply"])
 
 
 class Pybuild1(FullPybuild):
@@ -606,6 +606,8 @@ class Pybuild1(FullPybuild):
                 )
                 for doc_path in set(install_dir.DOC) | {
                     "README*",
+                    "readme*",
+                    "ReadMe*",
                     "ChangeLog",
                     "CHANGELOG*",
                     "AUTHORS*",
@@ -754,4 +756,32 @@ class Pybuild1(FullPybuild):
                     dest=dest,
                 )
             )
-            shutil.move(file, os.path.join(self.D, dest, self.PN))
+            # Handle multiple files of the same name.
+            #
+            # Such files will cause errors on Windows, however it is also a logic error since
+            # different pieces of documentation with the same name are probably from
+            # different parts of the package (e.g. main mod and a patch) and should
+            # probably all be installed side by side.
+            #
+            # Instead, rename them so they have unique names.
+            if os.environ.get("CASE_INSENSITIVE_FILES", False):
+                path = os.path.join(dest, self.PN, os.path.basename(file))
+                ci_path = ci_exists(path, prefix=self.D)
+                # Skip file if identical to one which already exists
+                if ci_path and cmp(file, ci_path, shallow=False):
+                    continue
+                if ci_path:
+                    dest_path = make_unique_filename(
+                        os.path.join(self.D, path), case_insensitive=True
+                    )
+                else:
+                    dest_path = os.path.join(self.D, dest, self.PN)
+            else:
+                dest_path = os.path.join(self.D, dest, self.PN, os.path.basename(file))
+                if os.path.exists(dest_path):
+                    dest_path = make_unique_filename(os.path.join(self.D, path))
+
+            try:
+                shutil.move(file, dest_path)
+            except OSError:
+                shutil.copy2(file, dest_path)
