@@ -7,14 +7,15 @@ use pyo3::{exceptions::PyOSError, PyErr};
 #[derive(Debug, Display, From)]
 pub enum Error {
     #[display(fmt = "{}: {}", _0, _1)]
-    IOError(String, std::io::Error),
+    IO(String, std::io::Error),
     #[display(fmt = "{}: {}", _0, _1)]
-    YamlError(String, serde_yaml::Error),
-    LanguageIdentifierError(unic_langid::LanguageIdentifierError),
-    StdError(Box<dyn std::error::Error>),
+    Yaml(String, serde_yaml::Error),
+    LanguageIdentifier(unic_langid::LanguageIdentifierError),
+    Std(Box<dyn std::error::Error>),
     UnsupportedHashType(String),
     #[display(fmt = "Error when parsing file {}: {}", _0, _1)]
-    PluginError(String, esplugin::Error),
+    Plugin(String, esplugin::Error),
+    Tantivy(tantivy::TantivyError),
 }
 
 impl std::convert::From<Error> for PyErr {
