@@ -1,14 +1,13 @@
 #[macro_use]
 extern crate serde_with;
 
-mod conflicts;
 mod dds;
 mod error;
+mod index;
 mod metadata;
 mod news;
 mod yaml;
 
-use crate::conflicts::conflicts;
 use crate::dds::get_dds_dimensions;
 use crate::metadata::{
     CategoryMetadata, Group, GroupDeclaration, PackageMetadata, Person, Upstream,
@@ -20,12 +19,10 @@ use esplugin::{GameId, Plugin};
 use fluent_bundle::types::FluentValue;
 use fluent_templates::Loader;
 use std::collections::HashMap;
-use std::collections::HashSet;
 use std::io::BufRead;
 use std::io::BufReader;
 use std::path::Path;
 use unic_langid::LanguageIdentifier;
-use walkdir::WalkDir;
 
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyFloat, PyLong};
@@ -128,55 +125,15 @@ fn main() {
         Ok(parse_yaml(filename)?)
     }
 
-    #[pyfunction]
-    fn file_conflicts(dirs: Vec<String>, ignore: Vec<&str>) -> PyResult<()> {
-        let mut entries = Vec::new();
-        let mut ignore_set = HashSet::new();
-        for extstr in ignore {
-            for val in extstr.split(',') {
-                ignore_set.insert(val.to_string().to_lowercase());
-            }
-        }
-        for dir in dirs {
-            let mut files = HashSet::new();
-            for file in WalkDir::new(&dir)
-                .into_iter()
-                .filter_map(Result::ok)
-                .filter(|e| {
-                    !e.file_type().is_dir()
-                        && e.path()
-                            .extension()
-                            .map(|ext| {
-                                !ignore_set.contains(&ext.to_str().unwrap_or("").to_lowercase())
-                            })
-                            .unwrap_or(true)
-                })
-            {
-                if let Ok(suffix) = file.path().strip_prefix(&dir) {
-                    files.insert(suffix.display().to_string());
-                } else {
-                    panic!(
-                        "Internal Error: File {} is not in directory {}!",
-                        file.path().display(),
-                        &dir
-                    );
-                }
-            }
-            entries.push((dir.to_string(), files));
-        }
-        conflicts("Directories", "Files", &entries)?;
-        Ok(())
-    }
-
     #[pyfunction]
     fn get_masters(filename: String) -> PyResult<Vec<String>> {
         let mut plugin = Plugin::new(GameId::Morrowind, Path::new(&filename));
         plugin
             .parse_file(true)
-            .map_err(|x| crate::error::Error::PluginError(filename.clone(), x))?;
+            .map_err(|x| crate::error::Error::Plugin(filename.clone(), x))?;
         let list = plugin
             .masters()
-            .map_err(|x| crate::error::Error::PluginError(filename.clone(), x))?;
+            .map_err(|x| crate::error::Error::Plugin(filename.clone(), x))?;
         Ok(list)
     }
 
@@ -193,7 +150,7 @@ fn main() {
             Err(_) => {
                 let gil = Python::acquire_gil();
                 let py = gil.python();
-                let log = py.import("portmod.log")?;
+                let log = py.import("portmodlib.log")?;
                 log.getattr("warn_once")?.call(
                     (format!(
                         "User language identifier \"{}\" could not be parsed",
@@ -280,7 +237,7 @@ fn main() {
                         if size > 128 * 1024 {
                             hasher.update_rayon(&buffer[0..size]);
                         } else {
-                            hasher.update(&buffer);
+                            hasher.update(buffer);
                         }
                         reader.consume(size);
                     }
@@ -293,7 +250,7 @@ fn main() {
                     results.insert("SHA256", get_hash(sha2::Sha256::new(), &mut reader)?);
                 }
                 "BLAKE2B" => {
-                    results.insert("BLAKE2B", get_hash(blake2::Blake2b::new(), &mut reader)?);
+                    results.insert("BLAKE2B", get_hash(blake2::Blake2b512::new(), &mut reader)?);
                 }
                 "MD5" => {
                     results.insert("MD5", get_hash(md5::Md5::new(), &mut reader)?);
@@ -308,10 +265,20 @@ fn main() {
             .collect())
     }
 
+    #[pyfunction]
+    fn update_index(index_path: &str, packages: Vec<HashMap<String, String>>) -> PyResult<()> {
+        Ok(index::update_index(index_path, packages).map_err(error::Error::Tantivy)?)
+    }
+
+    #[pyfunction]
+    /// Returns a json representation of the packages resulting from the query.
+    fn query(index_path: &str, prefix: &str, query: &str, limit: usize) -> PyResult<Vec<String>> {
+        Ok(index::query(index_path, prefix, query, limit).map_err(error::Error::Tantivy)?)
+    }
+
     #[pymodule]
     /// A Python module implemented in Rust.
     fn portmod(_: Python, m: &PyModule) -> PyResult<()> {
-        m.add_wrapped(wrap_pyfunction!(file_conflicts))?;
         m.add_wrapped(wrap_pyfunction!(get_masters))?;
         m.add_wrapped(wrap_pyfunction!(dds_dimensions))?;
         m.add_wrapped(wrap_pyfunction!(parse_package_metadata))?;
@@ -322,6 +289,8 @@ fn main() {
         m.add_wrapped(wrap_pyfunction!(parse_news))?;
         m.add_wrapped(wrap_pyfunction!(l10n_lookup))?;
         m.add_wrapped(wrap_pyfunction!(_get_hash))?;
+        m.add_wrapped(wrap_pyfunction!(update_index))?;
+        m.add_wrapped(wrap_pyfunction!(query))?;
         m.add_class::<PackageMetadata>()?;
         m.add_class::<Upstream>()?;
         m.add_class::<CategoryMetadata>()?;
