@@ -7,8 +7,9 @@ Tests for use flag aliases
 
 import pytest
 
+from portmod.config.use import remove_use
 from portmod.globals import env
-from portmod.loader import load_installed_pkg
+from portmod.loader import SandboxedError, load_installed_pkg
 from portmod.merge import configure
 from portmod.repos import get_repos
 from portmodlib.atom import Atom
@@ -27,7 +28,7 @@ def setup():
 
 def test_simple_alias(setup):
     """Tests that use flag aliases match the installed state of the aliased package"""
-    configure(["test/test2"], no_confirm=True)
+    configure(["test/test2"])
 
     pkg = load_installed_pkg(Atom("test/test2"))
     assert pkg
@@ -38,8 +39,6 @@ def test_simple_alias(setup):
         ["test/test2", "test/test7"],
         deep=True,
         update=True,
-        newuse=True,
-        no_confirm=True,
         verbose=True,
     )
 
@@ -48,12 +47,12 @@ def test_simple_alias(setup):
     assert "alias1" in pkg.INSTALLED_USE
     assert "alias2" not in pkg.INSTALLED_USE
 
-    configure(["test/test2", "test/test7"], no_confirm=True, delete=True)
+    configure(["test/test2", "test/test7"], delete=True)
 
 
 def test_alias_with_use_flag(setup):
     """Tests that use flag aliases with use flag dependencies behave correctly"""
-    configure(["test/test2"], no_confirm=True)
+    configure(["test/test2"])
 
     pkg = load_installed_pkg(Atom("test/test2"))
     assert pkg
@@ -64,8 +63,6 @@ def test_alias_with_use_flag(setup):
         ["test/test2", "test/test4"],
         deep=True,
         update=True,
-        newuse=True,
-        no_confirm=True,
     )
 
     pkg = load_installed_pkg(Atom("test/test2"))
@@ -77,11 +74,23 @@ def test_alias_with_use_flag(setup):
         ["test/test2", "test/test4[foo]"],
         deep=True,
         update=True,
-        newuse=True,
-        no_confirm=True,
     )
 
     pkg = load_installed_pkg(Atom("test/test2"))
     assert pkg
     assert "alias1" not in pkg.INSTALLED_USE
     assert "alias2" in pkg.INSTALLED_USE
+
+    configure(["test/test2", "test/test4"], delete=True)
+    remove_use("foo", Atom("test/test4"))
+
+
+def test_alias_nofetch(setup):
+    """Tests that use flag aliases work correctly in the scope of pkg_nofetch"""
+    # Should raise an exception if
+    with pytest.raises(SandboxedError):
+        configure(
+            ["test/test-nofetch", "test/test4[foo]"],
+            deep=True,
+            update=True,
+        )
