@@ -32,7 +32,7 @@ def test_deps(setup):
     """
     # test3 test4 and test5 should resolve correctly if
     # the foo flag is disabled for mod 3
-    configure(["test/test3", "test/test5"], no_confirm=True)
+    configure(["test/test3", "test/test5"])
     mod3 = load_installed_pkg(Atom("test/test3"))
     mod4 = load_installed_pkg(Atom("test/test4"))
     mod5 = load_installed_pkg(Atom("test/test5"))
@@ -44,14 +44,14 @@ def test_deps(setup):
 
     # test3, test4, test5, and test6 should not resolve correctly
     with pytest.raises(DepError):
-        configure(["test/test3", "test/test5", "test/test6"], no_confirm=True)
+        configure(["test/test3", "test/test5", "test/test6"])
 
 
 def test_unsolveable(setup):
     """Tests that mods that cannot be resolved fail to resolve"""
 
     with pytest.raises(DepError):
-        configure(["test/test-useless"], no_confirm=True)
+        configure(["test/test-useless"])
 
 
 def test_weight(setup):
@@ -59,14 +59,14 @@ def test_weight(setup):
 
     # Note test7 will cause other mods to be pulled into the formula due to conditionals,
     # but by default shouldn't depend on anything
-    configure(["test/test7"], no_confirm=True)
+    configure(["test/test7"])
     assert len(list(load_all_installed())) == 1
     assert all(mod.PN != "test" for mod in load_all_installed())
 
 
 def test_usedep_cli(setup):
     """Tests that use dependencies are satisfied when passed on the command line"""
-    configure(["test/test4[foo,bar,-baz]"], no_confirm=True)
+    configure(["test/test4[foo,bar,-baz]"])
     mod = load_installed_pkg(Atom("test/test4"))
     assert mod
     assert mod.INSTALLED_USE >= {"foo", "bar"}
