@@ -35,7 +35,7 @@ USE_EXPAND = "FOO"
 """,
             file=configfile,
         )
-    get_config.cache_clear()  # type: ignore
+    get_config.cache_clear()
     with pytest.raises(UserWarning):
         get_config()
 
@@ -47,7 +47,7 @@ ARCH = "BAR"
             file=configfile,
         )
 
-    get_config.cache_clear()  # type: ignore
+    get_config.cache_clear()
     with pytest.raises(UserWarning):
         get_config()
 
@@ -59,6 +59,6 @@ TEST_PROFILE_ONLY = "BAR"
             file=configfile,
         )
 
-    get_config.cache_clear()  # type: ignore
+    get_config.cache_clear()
     with pytest.raises(UserWarning):
         get_config()
