@@ -5,6 +5,7 @@
 Tests some otherwise untested parts of the interface
 """
 
+import io
 import os
 import sys
 
@@ -43,20 +44,21 @@ def test_sync():
 
 
 def test_info():
-    """Tests that portmod sync works correctly"""
+    """Tests that portmod info works correctly"""
     sys.argv = ["portmod", "test", "info"]
     with pytest.raises(SystemExit):
         main()
 
 
-def test_search():
-    """Tests that portmod sync works correctly"""
+def test_search(monkeypatch):
+    """Tests that portmod search works correctly"""
     sys.argv = ["portmod", "test", "search", "test"]
+    monkeypatch.setattr("sys.stdin", io.StringIO("\n"))
     main()
 
 
 def test_use():
-    """Tests that portmod sync works correctly"""
+    """Tests that portmod use works correctly"""
     sys.argv = ["portmod", "test", "use", "-E", "foo"]
     main()
     sys.argv = ["portmod", "test", "merge", "test4", "--no-confirm"]
