@@ -4,8 +4,8 @@
 import pytest
 
 from portmod._deps import resolve
-from portmod.config.sets import get_set
-from portmod.config.use import add_use
+from portmod.config.sets import add_set, get_set, remove_set
+from portmod.config.use import add_global_use
 from portmod.loader import load_installed_pkg
 from portmod.merge import configure
 from portmod.transactions import Downgrade, New, Reinstall, Update
@@ -32,7 +32,7 @@ def test_simple(setup):
     assert transactions.pkgs[0].pkg.CPN == "test/test"
     assert isinstance(transactions.pkgs[0], New)
 
-    configure(["test/test"], no_confirm=True)
+    configure(["test/test"])
     transactions = resolve(selected, set(), selected, selected, set())
     assert len(transactions.pkgs) == 1
     assert transactions.pkgs[0].pkg.CPN == "test/test"
@@ -45,7 +45,7 @@ def test_rebuild(setup):
     use the Category-PackageName format
     """
     selected = {Atom("~test/test-1.0")}
-    configure(selected, no_confirm=True)
+    configure(selected)
     transactions = resolve(selected, set(), selected, selected, set())
     assert len(transactions.pkgs) == 1
     assert transactions.pkgs[0].pkg.CPN == "test/test"
@@ -65,7 +65,7 @@ def test_upgrade(setup):
 def test_oneshot(setup):
     """Tests that oneshot resolves correctly"""
     selected = {Atom("test/test")}
-    configure(selected, no_confirm=True)
+    configure(selected)
     transactions = resolve(selected, set(), selected, set(), set())
     assert len(transactions.pkgs) == 1
     assert not version_gt(transactions.pkgs[0].pkg.PVR, "2.0")
@@ -76,7 +76,7 @@ def test_oneshot(setup):
 
 def test_downgrade(setup):
     """Tests that downgrades resolve correctly"""
-    configure(["=test/test-2.0"], no_confirm=True)
+    configure(["=test/test-2.0"])
     selected = {Atom("=test/test-1.0")}
     transactions = resolve(selected, set(), selected, selected, set())
     assert len(transactions.pkgs) == 1
@@ -92,19 +92,17 @@ def test_auto_depclean(setup):
     test7-1.0 could be downgraded to test7-0.1 to remove the dependencies
     And test7-1.0's flags could be disabled to remove the dependencies.
     """
-    configure(["=test/test7-1.0[baz]"], no_confirm=True)
+    configure(["=test/test7-1.0[baz]"])
     pkg = load_installed_pkg(Atom("test/test5"))
     assert pkg
     transactions = resolve(
-        {Atom("test/test7")},
-        set(),
-        set(),
-        set(),
-        {"world"},
+        enabled={Atom("test/test7")},
+        disabled=set(),
+        explicit={Atom("test/test7")},
+        selected=set(),
+        selected_sets={"world"},
         update=True,
-        newuse=True,
         deep=True,
-        noreplace=True,
         depclean=True,
     )
     assert len(transactions.pkgs) == 0
@@ -114,28 +112,23 @@ def test_upgrade_configuration(setup):
     """
     Tests that upgrades will pull in new packages and change configuration if necessary
     """
-    configure(["@installed"], no_confirm=True, delete=True)
+    configure(["@installed"], delete=True)
     configure(
         ["=test/test7-0.1"],
-        no_confirm=True,
         update=True,
-        newuse=True,
         deep=True,
-        noreplace=True,
     )
-    add_use("baz")
+    add_global_use("baz")
     pkg = load_installed_pkg(Atom("test/test5"))
     assert not pkg
     transactions = resolve(
-        get_set("world"),
-        set(),
-        set(),
-        set(),
-        {"world"},
+        enabled=get_set("world"),
+        disabled=set(),
+        explicit=get_set("world"),
+        selected=set(),
+        selected_sets={"world"},
         update=True,
-        newuse=True,
         deep=True,
-        noreplace=True,
     )
     for change in transactions.config:
         raise Exception(f"Unexpected configuration change {change}")
@@ -147,3 +140,30 @@ def test_upgrade_configuration(setup):
             assert change.pkg.PN in {"test5", "test4"}
         else:
             raise Exception(f"Unexpected transaction ({change.REPR}) {change.pkg}")
+
+    configure(["test/test7"], depclean=True)
+
+
+def test_nondeep_depth(setup):
+    """
+    Tests that, when not using deep mode, packages which are in the world set but
+    have not been installed will pull in all their dependencies
+    """
+    add_set("selected-packages", Atom("=test/test6-1.0"))
+    transactions = resolve(
+        enabled=set(),
+        disabled=set(),
+        explicit=set(),
+        selected=set(),
+        selected_sets=set(),
+        update=True,
+    )
+    # test6 depends on test3 which depends on test4
+    packages = ["test6", "test3", "test4"]
+    for change in transactions.pkgs:
+        assert isinstance(change, New)
+        assert change.pkg.PN in packages
+        packages.remove(change.pkg.PN)
+
+    assert not packages
+    remove_set("selected-packages", Atom("=test/test6-1.0"))
