@@ -18,7 +18,7 @@ from zipfile import ZipFile
 
 import pytest
 
-from portmod.config.use import add_use, remove_use
+from portmod.config.use import add_global_use, remove_use
 from portmod.globals import env
 from portmod.loader import load_installed_pkg
 from portmod.merge import configure
@@ -58,11 +58,9 @@ def test_sort_vfs(setup):
     # Install mods
     configure(
         ["test/test-1.0", "test/test2-1.0"],
-        no_confirm=True,
-        noreplace=True,
-        newuse=True,
+        update=True,
     )
-    pkg1 = load_installed_pkg(Atom("test/test"))
+    pkg1 = load_installed_pkg(Atom("test/test-1.0"))
     pkg2 = load_installed_pkg(Atom("test/test2"))
     assert pkg1 and pkg2
     path1 = os.path.normpath(
@@ -102,9 +100,7 @@ def test_user_override(setup):
 
     configure(
         ["test/test-1.0", "test/test2-1.0"],
-        no_confirm=True,
-        noreplace=True,
-        newuse=True,
+        update=True,
     )
     sort_vfs()
 
@@ -145,9 +141,7 @@ def test_user_cycle(setup):
         with pytest.raises(CycleException):
             configure(
                 ["test/test-1.0", "test/test2-1.0"],
-                no_confirm=True,
-                noreplace=True,
-                newuse=True,
+                update=True,
             )
             sort_vfs()
     finally:
@@ -163,9 +157,7 @@ def test_data_override_flag(setup):
     remove_use("foo")
     configure(
         ["test/test6-1.0", "test/test7-1.0"],
-        no_confirm=True,
-        noreplace=True,
-        newuse=True,
+        update=True,
     )
     sort_vfs()
 
@@ -185,8 +177,8 @@ def test_data_override_flag(setup):
     assert path2 in lines
     assert lines.index(path1) < lines.index(path2)
 
-    add_use("foo")
-    configure(["test/test7-1.0"], no_confirm=True, noreplace=True, newuse=True)
+    add_global_use("foo")
+    configure(["test/test7-1.0"], update=True)
     sort_vfs()
 
     lines = get_vfs_dirs()
@@ -201,9 +193,7 @@ def test_find_file(setup):
     """
     configure(
         ["test/test6-1.0", "test/test7-1.0[foo]"],
-        no_confirm=True,
-        noreplace=True,
-        newuse=True,
+        update=True,
     )
     pkg1 = load_installed_pkg(Atom("test/test6"))
     assert pkg1
@@ -223,7 +213,7 @@ def test_local_vfs(setup):
 
     sort_vfs()
 
-    pkg1 = load_installed_pkg(Atom("test/test"))
+    pkg1 = load_installed_pkg(Atom("test/test-1.0"))
     pkg2 = load_installed_pkg(Atom("test/test2"))
     assert pkg1 and pkg2
     path1 = os.path.normpath(
@@ -265,7 +255,7 @@ def test_archives(setup):
 
 def test_remove_vfs(setup):
     # Remove mods
-    configure(["test/test-1.0", "test/test2-1.0"], no_confirm=True, noreplace=True)
+    configure(["test/test-1.0", "test/test2-1.0"])
 
     pkg1 = load_installed_pkg(Atom("test/test"))
     pkg2 = load_installed_pkg(Atom("test/test2"))
@@ -278,7 +268,7 @@ def test_remove_vfs(setup):
     )
 
     # Remove mods
-    configure(["test/test-1.0", "test/test2-1.0"], no_confirm=True, depclean=True)
+    configure(["test/test-1.0", "test/test2-1.0"], depclean=True)
 
     # Check that config is no longer contains their entries
     lines = get_vfs_dirs()
